/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwell.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwell *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwell_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwell_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwell));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwell(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwell_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwell();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwell::Heavy_vSwell(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_j8Zvgv8e, &hTable_pL5ZPjuS);
  numBytes += sTabread_init(&sTabread_5rPvTe9S, &hTable_pL5ZPjuS, true);
  numBytes += sRPole_init(&sRPole_6DXhjDyB);
  numBytes += sEnv_init(&sEnv_A3Fb12fX, 1024, 512);
  numBytes += sLine_init(&sLine_wDsGC7V7);
  numBytes += cSlice_init(&cSlice_6b1HkK7o, 1, -1);
  numBytes += cSlice_init(&cSlice_827oLLVL, 1, -1);
  numBytes += cVar_init_f(&cVar_8H2q190a, 0.0f);
  numBytes += cIf_init(&cIf_CxhLL2TE, false);
  numBytes += cBinop_init(&cBinop_jrRoNPfp, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_azPAt4yx, 1, -1);
  numBytes += cSlice_init(&cSlice_zFn9rWkA, 1, -1);
  numBytes += cVar_init_f(&cVar_P29F9CB0, 0.0f);
  numBytes += cIf_init(&cIf_4B8yR1Mg, false);
  numBytes += cBinop_init(&cBinop_2FPvcnGx, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_LmL0nFeZ, 0.0f);
  numBytes += cVar_init_f(&cVar_utdqRiG1, 0.0f);
  numBytes += cBinop_init(&cBinop_1V7ZqqFj, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_qF63uqOU, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_g6tftt7m, 2, 1);
  numBytes += cSlice_init(&cSlice_I1x5DUil, 1, 1);
  numBytes += cSlice_init(&cSlice_BmiTcvFe, 0, 1);
  numBytes += cVar_init_f(&cVar_ZU4JVK4a, 0.0f);
  numBytes += cIf_init(&cIf_WhvR3LLq, false);
  numBytes += cIf_init(&cIf_sD51ll8e, false);
  numBytes += cIf_init(&cIf_cTDYvHaL, false);
  numBytes += cIf_init(&cIf_3OUmg7tE, false);
  numBytes += cIf_init(&cIf_MUsNBwF2, false);
  numBytes += cBinop_init(&cBinop_ue0Osn69, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_uFEyszll, 10.0f);
  numBytes += cPack_init(&cPack_uMf0UmrO, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_7SDKET0N, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_hJUoWu1l, 10.0f);
  numBytes += cPack_init(&cPack_gdzMyWl4, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_HDrYTtJY, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_NzvYWfRC, 10.0f);
  numBytes += cPack_init(&cPack_gwZwqzgf, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_kZFSrVSh, 1e-07f);
  numBytes += cIf_init(&cIf_EsS8JCRu, true);
  numBytes += cVar_init_f(&cVar_XwSRP1Hx, 1e-07f);
  numBytes += cVar_init_f(&cVar_uFRVPOuf, 1e-07f);
  numBytes += sVarf_init(&sVarf_jRo4UGYG, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_1htamooA, 0.0f);
  numBytes += cVar_init_f(&cVar_iXfg5bnU, 20.0f);
  numBytes += cBinop_init(&cBinop_NCFLBMLm, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_zJ8jIwyD, 0.0f);
  numBytes += cSlice_init(&cSlice_B9I5Lss3, 1, -1);
  numBytes += cSlice_init(&cSlice_4I2hdYbQ, 1, -1);
  numBytes += cVar_init_f(&cVar_fp4iSUJB, 0.0f);
  numBytes += cVar_init_f(&cVar_vNcH72bS, 20.0f);
  numBytes += cVar_init_f(&cVar_o6HeqYuH, 0.0f);
  numBytes += cVar_init_f(&cVar_h9nAQqzd, 0.0f);
  numBytes += cVar_init_f(&cVar_BwFnLBQt, 0.0f);
  numBytes += cSlice_init(&cSlice_MBqoSe59, 1, 1);
  numBytes += cSlice_init(&cSlice_MdnuApO2, 0, 1);
  numBytes += cBinop_init(&cBinop_lEPcUXDR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VW2szoV8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PhkkIvte, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_sdAaqySD, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ROA6xa5H, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_Ptdbe8cD, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_yEB0haEa, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_avKsy8Tu, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_f5pIZrWE, 5.0f);
  numBytes += cVar_init_f(&cVar_DGWWEJSi, 500.0f);
  numBytes += cBinop_init(&cBinop_0h8xHIcU, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_GNJAUDgN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aU9j3ewi, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_Fb7AMfoh, 0.0f);
  numBytes += cDelay_init(this, &cDelay_rpEG4Hn3, 0.0f);
  numBytes += hTable_init(&hTable_pL5ZPjuS, 256);
  numBytes += cTabhead_init(&cTabhead_Gxt7fDiV, &hTable_pL5ZPjuS);
  numBytes += cVar_init_s(&cVar_VwJd4xCz, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_MqFu0rxK, 8.0f);
  numBytes += cDelay_init(this, &cDelay_6yev6IUj, 0.0f);
  numBytes += cBinop_init(&cBinop_jlITOlCg, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_7l67yeek, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_txCZqHBQ, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_iBpN8VDL, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_9unGfAx3, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_hmJ9xzyt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GK49M8a7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1MsESKbQ, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwell::~Heavy_vSwell() {
  sEnv_free(&sEnv_A3Fb12fX);
  cPack_free(&cPack_uMf0UmrO);
  cPack_free(&cPack_gdzMyWl4);
  cPack_free(&cPack_gwZwqzgf);
  hTable_free(&hTable_pL5ZPjuS);
}

HvTable *Heavy_vSwell::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_pL5ZPjuS; // del-1001-swell
    default: return nullptr;
  }
}

void Heavy_vSwell::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ww4v0mQQ_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_G6GUOarp_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FHfDKUpw_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IXzahg95_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cSVfDbib_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_B8pR1F7q_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SoR2sqzN_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qMZLMp4b_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8WYwtcVd_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dBjPdF3z_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_04r7aGd7_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sRn3aMHz_sendMessage);
      break;
    }
    case 0xE7A7BB75: { // Trigger_by_Audio_ON
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tFnTwFWg_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oQ9OoAg9_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wUDcIsjL_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Y0QmYIK3_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6mvdH8SZ_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwell::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 30.0f;
        info->maxVal = 85.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_by_Audio_ON";
        info->hash = 0xE7A7BB75;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 13;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwell::sEnv_A3Fb12fX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1V7ZqqFj, HV_BINOP_GREATER_THAN, 0, m, &cBinop_1V7ZqqFj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qF63uqOU, HV_BINOP_LESS_THAN, 0, m, &cBinop_qF63uqOU_sendMessage);
}

void Heavy_vSwell::cSwitchcase_Ne4bvTK3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6b1HkK7o, 0, m, &cSlice_6b1HkK7o_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_827oLLVL, 0, m, &cSlice_827oLLVL_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_naHSDtaS_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Yf3LM7S4_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_6b1HkK7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_8H2q190a, 0, m, &cVar_8H2q190a_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_8H2q190a, 0, m, &cVar_8H2q190a_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_827oLLVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_jrRoNPfp, HV_BINOP_NEQ, 1, m, &cBinop_jrRoNPfp_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_8H2q190a, 1, m, &cVar_8H2q190a_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_jrRoNPfp, HV_BINOP_NEQ, 1, m, &cBinop_jrRoNPfp_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_8H2q190a, 1, m, &cVar_8H2q190a_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_8H2q190a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WqZh53QX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_CxhLL2TE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TzJBAcCX_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P4Mjly5c_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_TzJBAcCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jrRoNPfp, HV_BINOP_NEQ, 1, m, &cBinop_jrRoNPfp_sendMessage);
}

void Heavy_vSwell::cCast_P4Mjly5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8H2q190a, 0, m, &cVar_8H2q190a_sendMessage);
}

void Heavy_vSwell::cBinop_jrRoNPfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CxhLL2TE, 1, m, &cIf_CxhLL2TE_sendMessage);
}

void Heavy_vSwell::cCast_Yf3LM7S4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CxhLL2TE, 0, m, &cIf_CxhLL2TE_sendMessage);
}

void Heavy_vSwell::cCast_naHSDtaS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jrRoNPfp, HV_BINOP_NEQ, 0, m, &cBinop_jrRoNPfp_sendMessage);
}

void Heavy_vSwell::cSwitchcase_59PaVUJh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_azPAt4yx, 0, m, &cSlice_azPAt4yx_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zFn9rWkA, 0, m, &cSlice_zFn9rWkA_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3AeUOaQn_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tuyI8ama_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_azPAt4yx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_P29F9CB0, 0, m, &cVar_P29F9CB0_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_P29F9CB0, 0, m, &cVar_P29F9CB0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_zFn9rWkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_2FPvcnGx, HV_BINOP_NEQ, 1, m, &cBinop_2FPvcnGx_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_P29F9CB0, 1, m, &cVar_P29F9CB0_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_2FPvcnGx, HV_BINOP_NEQ, 1, m, &cBinop_2FPvcnGx_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_P29F9CB0, 1, m, &cVar_P29F9CB0_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_P29F9CB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KhQ5qXhK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cIf_4B8yR1Mg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_64lxKSdF_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qlLXAXh4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cCast_qlLXAXh4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P29F9CB0, 0, m, &cVar_P29F9CB0_sendMessage);
}

void Heavy_vSwell::cCast_64lxKSdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2FPvcnGx, HV_BINOP_NEQ, 1, m, &cBinop_2FPvcnGx_sendMessage);
}

void Heavy_vSwell::cBinop_2FPvcnGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4B8yR1Mg, 1, m, &cIf_4B8yR1Mg_sendMessage);
}

void Heavy_vSwell::cCast_3AeUOaQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2FPvcnGx, HV_BINOP_NEQ, 0, m, &cBinop_2FPvcnGx_sendMessage);
}

void Heavy_vSwell::cCast_tuyI8ama_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4B8yR1Mg, 0, m, &cIf_4B8yR1Mg_sendMessage);
}

void Heavy_vSwell::cSwitchcase_WqZh53QX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OV7TE30y_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RiZxsITr_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_OV7TE30y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_utdqRiG1, 0, m, &cVar_utdqRiG1_sendMessage);
}

void Heavy_vSwell::cCast_RiZxsITr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZlwTnX5A_sendMessage(_c, 0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_EsS8JCRu, 0, m, &cIf_EsS8JCRu_sendMessage);
}

void Heavy_vSwell::cSwitchcase_KhQ5qXhK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EnQ9BR4f_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RorBrnxO_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_EnQ9BR4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LmL0nFeZ, 0, m, &cVar_LmL0nFeZ_sendMessage);
}

void Heavy_vSwell::cCast_RorBrnxO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d3Wnq9Ct_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_LmL0nFeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1V7ZqqFj, HV_BINOP_GREATER_THAN, 1, m, &cBinop_1V7ZqqFj_sendMessage);
}

void Heavy_vSwell::cVar_utdqRiG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qF63uqOU, HV_BINOP_LESS_THAN, 1, m, &cBinop_qF63uqOU_sendMessage);
}

void Heavy_vSwell::cBinop_1V7ZqqFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Ne4bvTK3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_qF63uqOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_59PaVUJh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_ZlwTnX5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1V7ZqqFj, HV_BINOP_GREATER_THAN, 1, m, &cBinop_1V7ZqqFj_sendMessage);
}

void Heavy_vSwell::cMsg_d3Wnq9Ct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_qF63uqOU, HV_BINOP_LESS_THAN, 1, m, &cBinop_qF63uqOU_sendMessage);
}

void Heavy_vSwell::cSlice_g6tftt7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_5U3t8azz_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_I1x5DUil_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_3OUmg7tE, 0, m, &cIf_3OUmg7tE_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_sD51ll8e, 0, m, &cIf_sD51ll8e_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_BmiTcvFe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_MUsNBwF2, 0, m, &cIf_MUsNBwF2_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_cTDYvHaL, 0, m, &cIf_cTDYvHaL_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_ZU4JVK4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4SSeoz74_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_WhvR3LLq, 0, m, &cIf_WhvR3LLq_sendMessage);
}

void Heavy_vSwell::cUnop_QjxigqjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iJHSKzeR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ue0Osn69, HV_BINOP_EQ, 1, m, &cBinop_ue0Osn69_sendMessage);
}

void Heavy_vSwell::cUnop_4DkLsI5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iJHSKzeR_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ue0Osn69, HV_BINOP_EQ, 1, m, &cBinop_ue0Osn69_sendMessage);
}

void Heavy_vSwell::cIf_WhvR3LLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_4DkLsI5k_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_QjxigqjZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_4SSeoz74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WhvR3LLq, 1, m, &cIf_WhvR3LLq_sendMessage);
}

void Heavy_vSwell::cIf_sD51ll8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_enoRXJHf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_cTDYvHaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_3OUmg7tE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_enoRXJHf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cIf_MUsNBwF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_5U3t8azz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ue0Osn69, HV_BINOP_EQ, 0, m, &cBinop_ue0Osn69_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_qnJHr7hu_sendMessage);
}

void Heavy_vSwell::cBinop_iJHSKzeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mwSntFmw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uipeM4sV_sendMessage);
}

void Heavy_vSwell::cBinop_ue0Osn69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eeBexs9x_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YFhWyZZt_sendMessage);
}

void Heavy_vSwell::cCast_YFhWyZZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MUsNBwF2, 1, m, &cIf_MUsNBwF2_sendMessage);
}

void Heavy_vSwell::cCast_eeBexs9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sD51ll8e, 1, m, &cIf_sD51ll8e_sendMessage);
}

void Heavy_vSwell::cCast_uipeM4sV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cTDYvHaL, 1, m, &cIf_cTDYvHaL_sendMessage);
}

void Heavy_vSwell::cCast_mwSntFmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3OUmg7tE, 1, m, &cIf_3OUmg7tE_sendMessage);
}

void Heavy_vSwell::cBinop_qnJHr7hu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwell::cSwitchcase_38vuJzIE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_PX8Z4Qlz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_PX8Z4Qlz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uFEyszll, 1, m, &cDelay_uFEyszll_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q4Oghbza_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_uFEyszll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uFEyszll, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RPuQ71s8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6cYcJlaR_sendMessage);
  cSwitchcase_TPzIUKmt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_PX8Z4Qlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uFEyszll, 0, m, &cDelay_uFEyszll_sendMessage);
}

void Heavy_vSwell::cCast_q4Oghbza_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uFEyszll, 0, m, &cDelay_uFEyszll_sendMessage);
}

void Heavy_vSwell::cPack_uMf0UmrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_olS3A60e_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_7SDKET0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MbMXsY2Q_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_JuJw5TGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_38vuJzIE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_80B916yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_uMf0UmrO, 0, m, &cPack_uMf0UmrO_sendMessage);
}

void Heavy_vSwell::cCast_ab6kJgmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7SDKET0N, 0, m, &cVar_7SDKET0N_sendMessage);
}

void Heavy_vSwell::cMsg_MbMXsY2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_wDsGC7V7, 0, m, NULL);
}

void Heavy_vSwell::cMsg_olS3A60e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_wDsGC7V7, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_TPzIUKmt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_H0lcSVjw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_H0lcSVjw_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hJUoWu1l, 1, m, &cDelay_hJUoWu1l_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FI7gTqzQ_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_hJUoWu1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hJUoWu1l, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2wkj0Z1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QMWFPkIu_sendMessage);
  cSwitchcase_gBKNx0hD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_H0lcSVjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hJUoWu1l, 0, m, &cDelay_hJUoWu1l_sendMessage);
}

void Heavy_vSwell::cCast_FI7gTqzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hJUoWu1l, 0, m, &cDelay_hJUoWu1l_sendMessage);
}

void Heavy_vSwell::cPack_gdzMyWl4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bAobme5c_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_HDrYTtJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KHtl3QHR_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_ow6jyiSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_TPzIUKmt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_6cYcJlaR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_gdzMyWl4, 0, m, &cPack_gdzMyWl4_sendMessage);
}

void Heavy_vSwell::cCast_RPuQ71s8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HDrYTtJY, 0, m, &cVar_HDrYTtJY_sendMessage);
}

void Heavy_vSwell::cMsg_KHtl3QHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_wDsGC7V7, 0, m, NULL);
}

void Heavy_vSwell::cMsg_bAobme5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_wDsGC7V7, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_gBKNx0hD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ex4VagOb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ex4VagOb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_NzvYWfRC, 1, m, &cDelay_NzvYWfRC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6nf1X8k8_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_NzvYWfRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NzvYWfRC, m);
}

void Heavy_vSwell::cMsg_Ex4VagOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NzvYWfRC, 0, m, &cDelay_NzvYWfRC_sendMessage);
}

void Heavy_vSwell::cCast_6nf1X8k8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NzvYWfRC, 0, m, &cDelay_NzvYWfRC_sendMessage);
}

void Heavy_vSwell::cPack_gwZwqzgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XK8NBKtB_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_kZFSrVSh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PwuEvIFy_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cMsg_7qYTRW3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_gBKNx0hD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_2wkj0Z1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kZFSrVSh, 0, m, &cVar_kZFSrVSh_sendMessage);
}

void Heavy_vSwell::cCast_QMWFPkIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_gwZwqzgf, 0, m, &cPack_gwZwqzgf_sendMessage);
}

void Heavy_vSwell::cMsg_PwuEvIFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_wDsGC7V7, 0, m, NULL);
}

void Heavy_vSwell::cMsg_XK8NBKtB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_wDsGC7V7, 0, m, NULL);
}

void Heavy_vSwell::cIf_EsS8JCRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E4BUM3Zo_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OKKwMcIG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSwitchcase_Dfhu2Le2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iA3EGRll_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_iA3EGRll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E4BUM3Zo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OKKwMcIG_sendMessage);
}

void Heavy_vSwell::cVar_XwSRP1Hx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1mdVPkje_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_uFRVPOuf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_gwZwqzgf, 1, m, &cPack_gwZwqzgf_sendMessage);
}

void Heavy_vSwell::cMsg_MvxoD8VL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RrstS4dI_sendMessage);
}

void Heavy_vSwell::cSystem_RrstS4dI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VW2szoV8, HV_BINOP_MULTIPLY, 1, m, &cBinop_VW2szoV8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lEPcUXDR, HV_BINOP_MULTIPLY, 1, m, &cBinop_lEPcUXDR_sendMessage);
}

void Heavy_vSwell::cSwitchcase_IYeDHhYk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_5H2FAvSQ_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_5H2FAvSQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_unRYontC_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_1htamooA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1htamooA, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1htamooA, 0, m, &cDelay_1htamooA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zJ8jIwyD, 0, m, &cVar_zJ8jIwyD_sendMessage);
}

void Heavy_vSwell::cCast_unRYontC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5H2FAvSQ_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_1htamooA, 0, m, &cDelay_1htamooA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zJ8jIwyD, 0, m, &cVar_zJ8jIwyD_sendMessage);
}

void Heavy_vSwell::cMsg_9PW7H3Eg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YUVaARjc_sendMessage);
}

void Heavy_vSwell::cSystem_YUVaARjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_m5b70XPp_sendMessage);
}

void Heavy_vSwell::cVar_iXfg5bnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NCFLBMLm, HV_BINOP_MULTIPLY, 0, m, &cBinop_NCFLBMLm_sendMessage);
}

void Heavy_vSwell::cMsg_5H2FAvSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1htamooA, 0, m, &cDelay_1htamooA_sendMessage);
}

void Heavy_vSwell::cBinop_20DUGvhu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1htamooA, 2, m, &cDelay_1htamooA_sendMessage);
}

void Heavy_vSwell::cBinop_m5b70XPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NCFLBMLm, HV_BINOP_MULTIPLY, 1, m, &cBinop_NCFLBMLm_sendMessage);
}

void Heavy_vSwell::cBinop_NCFLBMLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_20DUGvhu_sendMessage);
}

void Heavy_vSwell::cVar_zJ8jIwyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PhkkIvte, HV_BINOP_SUBTRACT, 0, m, &cBinop_PhkkIvte_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_2OkfKukP_sendMessage);
}

void Heavy_vSwell::cSwitchcase_cVDKjMgi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_48bkOg7g_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vPEauY2g_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cCast_48bkOg7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BwFnLBQt, 0, m, &cVar_BwFnLBQt_sendMessage);
}

void Heavy_vSwell::cCast_vPEauY2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NpNxNSKt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4Miz0lVq_sendMessage);
}

void Heavy_vSwell::cSwitchcase_0j4HefHj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_B9I5Lss3, 0, m, &cSlice_B9I5Lss3_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4I2hdYbQ, 0, m, &cSlice_4I2hdYbQ_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8ujRTMUx_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_MBqoSe59, 0, m, &cSlice_MBqoSe59_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_MdnuApO2, 0, m, &cSlice_MdnuApO2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mX8gdanI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vgsJ88qw_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cSlice_B9I5Lss3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_CYlJTeSs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_CYlJTeSs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_4I2hdYbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9I0pWd3l_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dNs52Nbo_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9I0pWd3l_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dNs52Nbo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cVar_fp4iSUJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sBctZIfB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3KcGzxsr_sendMessage);
}

void Heavy_vSwell::cVar_vNcH72bS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Peu7r6Hg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cSwitchcase_Peu7r6Hg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3Yfa400k_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_VW2szoV8, HV_BINOP_MULTIPLY, 0, m, &cBinop_VW2szoV8_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_ROA6xa5H, HV_BINOP_DIVIDE, 1, m, &cBinop_ROA6xa5H_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_iXfg5bnU, 0, m, &cVar_iXfg5bnU_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cCast_3Yfa400k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_efEDcENL_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cVar_o6HeqYuH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_avKsy8Tu, HV_BINOP_SUBTRACT, 1, m, &cBinop_avKsy8Tu_sendMessage);
}

void Heavy_vSwell::cVar_h9nAQqzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BwFnLBQt, 0, m, &cVar_BwFnLBQt_sendMessage);
}

void Heavy_vSwell::cVar_BwFnLBQt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sdAaqySD, HV_BINOP_ADD, 0, m, &cBinop_sdAaqySD_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yEB0haEa, HV_BINOP_ADD, 0, m, &cBinop_yEB0haEa_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_jRo4UGYG, m);
}

void Heavy_vSwell::cSlice_MBqoSe59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sBctZIfB_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3KcGzxsr_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cSlice_MdnuApO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K943kKAX_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ALsyZdXq_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_x67bTGgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zJ8jIwyD, 1, m, &cVar_zJ8jIwyD_sendMessage);
}

void Heavy_vSwell::cBinop_lEPcUXDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_x67bTGgB_sendMessage);
}

void Heavy_vSwell::cBinop_VW2szoV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_QZTv9tUS_sendMessage);
}

void Heavy_vSwell::cBinop_QZTv9tUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PhkkIvte, HV_BINOP_SUBTRACT, 1, m, &cBinop_PhkkIvte_sendMessage);
}

void Heavy_vSwell::cBinop_PhkkIvte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zJ8jIwyD, 1, m, &cVar_zJ8jIwyD_sendMessage);
}

void Heavy_vSwell::cMsg_XTcGYaki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_IYeDHhYk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_RKMyTJ4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_IYeDHhYk_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yEB0haEa, HV_BINOP_ADD, 1, m, &cBinop_yEB0haEa_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sdAaqySD, HV_BINOP_ADD, 1, m, &cBinop_sdAaqySD_sendMessage);
}

void Heavy_vSwell::cBinop_2OkfKukP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cVDKjMgi_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cBinop_sdAaqySD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BwFnLBQt, 1, m, &cVar_BwFnLBQt_sendMessage);
}

void Heavy_vSwell::cBinop_ROA6xa5H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ptdbe8cD, HV_BINOP_DIVIDE, 1, m, &cBinop_Ptdbe8cD_sendMessage);
}

void Heavy_vSwell::cBinop_Ptdbe8cD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yEB0haEa, HV_BINOP_ADD, 1, m, &cBinop_yEB0haEa_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_sdAaqySD, HV_BINOP_ADD, 1, m, &cBinop_sdAaqySD_sendMessage);
}

void Heavy_vSwell::cCast_3KcGzxsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ROA6xa5H, HV_BINOP_DIVIDE, 0, m, &cBinop_ROA6xa5H_sendMessage);
}

void Heavy_vSwell::cCast_sBctZIfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lEPcUXDR, HV_BINOP_MULTIPLY, 0, m, &cBinop_lEPcUXDR_sendMessage);
}

void Heavy_vSwell::cCast_ALsyZdXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_avKsy8Tu, HV_BINOP_SUBTRACT, 0, m, &cBinop_avKsy8Tu_sendMessage);
}

void Heavy_vSwell::cCast_K943kKAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_h9nAQqzd, 1, m, &cVar_h9nAQqzd_sendMessage);
}

void Heavy_vSwell::cCast_NpNxNSKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RKMyTJ4y_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_4Miz0lVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_h9nAQqzd, 0, m, &cVar_h9nAQqzd_sendMessage);
}

void Heavy_vSwell::cBinop_yEB0haEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o6HeqYuH, 0, m, &cVar_o6HeqYuH_sendMessage);
}

void Heavy_vSwell::cMsg_CYlJTeSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_IYeDHhYk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_iv9bsWvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_fp4iSUJB, 1, m, &cVar_fp4iSUJB_sendMessage);
}

void Heavy_vSwell::cMsg_efEDcENL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VW2szoV8, HV_BINOP_MULTIPLY, 0, m, &cBinop_VW2szoV8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ROA6xa5H, HV_BINOP_DIVIDE, 1, m, &cBinop_ROA6xa5H_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iXfg5bnU, 0, m, &cVar_iXfg5bnU_sendMessage);
}

void Heavy_vSwell::cCast_9I0pWd3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CYlJTeSs_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_dNs52Nbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mt7ujDjp_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yEB0haEa, HV_BINOP_ADD, 0, m, &cBinop_yEB0haEa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BwFnLBQt, 1, m, &cVar_BwFnLBQt_sendMessage);
}

void Heavy_vSwell::cBinop_avKsy8Tu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ptdbe8cD, HV_BINOP_DIVIDE, 0, m, &cBinop_Ptdbe8cD_sendMessage);
}

void Heavy_vSwell::cCast_Mt7ujDjp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RKMyTJ4y_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_vgsJ88qw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iv9bsWvj_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_mX8gdanI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XTcGYaki_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cCast_8ujRTMUx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fp4iSUJB, 0, m, &cVar_fp4iSUJB_sendMessage);
}

void Heavy_vSwell::cSwitchcase_Ionjj9Pb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_RhtskuxN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_RhtskuxN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_f5pIZrWE, 1, m, &cDelay_f5pIZrWE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tTq4nau5_sendMessage);
      break;
    }
  }
}

void Heavy_vSwell::cDelay_f5pIZrWE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_f5pIZrWE, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ab6kJgmJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_80B916yo_sendMessage);
  cSwitchcase_38vuJzIE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_RhtskuxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_f5pIZrWE, 0, m, &cDelay_f5pIZrWE_sendMessage);
}

void Heavy_vSwell::cCast_tTq4nau5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_f5pIZrWE, 0, m, &cDelay_f5pIZrWE_sendMessage);
}

void Heavy_vSwell::cVar_DGWWEJSi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0h8xHIcU, HV_BINOP_MULTIPLY, 0, m, &cBinop_0h8xHIcU_sendMessage);
}

void Heavy_vSwell::cMsg_mwUUXTYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_lsR14xWm_sendMessage);
}

void Heavy_vSwell::cSystem_lsR14xWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dSwNihov_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_0h8xHIcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_x2z2nD2d_sendMessage);
}

void Heavy_vSwell::cBinop_yE26mIXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0h8xHIcU, HV_BINOP_MULTIPLY, 1, m, &cBinop_0h8xHIcU_sendMessage);
}

void Heavy_vSwell::cMsg_dSwNihov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_yE26mIXR_sendMessage);
}

void Heavy_vSwell::cBinop_x2z2nD2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_kKowXaKt_sendMessage);
}

void Heavy_vSwell::cBinop_kKowXaKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_yxcSDYn6_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_aU9j3ewi, m);
}

void Heavy_vSwell::cBinop_yxcSDYn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GNJAUDgN, m);
}

void Heavy_vSwell::cMsg_nsrBTF7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_48OnyBUa_sendMessage);
}

void Heavy_vSwell::cSystem_48OnyBUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_j0nUBvyA_sendMessage);
}

void Heavy_vSwell::cDelay_Fb7AMfoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Fb7AMfoh, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rpEG4Hn3, 0, m, &cDelay_rpEG4Hn3_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Fb7AMfoh, 0, m, &cDelay_Fb7AMfoh_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_j8Zvgv8e, 1, m, NULL);
}

void Heavy_vSwell::cDelay_rpEG4Hn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rpEG4Hn3, m);
  cMsg_B5oix101_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cSwitchcase_dsiJFuFz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_41qHCxmN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwell::cBinop_1pvgt8kL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oJInV9Wt_sendMessage(_c, 0, m);
}

void Heavy_vSwell::hTable_pL5ZPjuS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zkal29Lm_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_Fb7AMfoh, 2, m, &cDelay_Fb7AMfoh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3lH7rKJi_sendMessage);
}

void Heavy_vSwell::cMsg_oJInV9Wt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_pL5ZPjuS, 0, m, &hTable_pL5ZPjuS_sendMessage);
}

void Heavy_vSwell::cBinop_j0nUBvyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_1pvgt8kL_sendMessage);
}

void Heavy_vSwell::cMsg_B5oix101_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_pL5ZPjuS, 0, m, &hTable_pL5ZPjuS_sendMessage);
}

void Heavy_vSwell::cCast_3lH7rKJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Fb7AMfoh, 0, m, &cDelay_Fb7AMfoh_sendMessage);
}

void Heavy_vSwell::cMsg_Zkal29Lm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_rpEG4Hn3, 2, m, &cDelay_rpEG4Hn3_sendMessage);
}

void Heavy_vSwell::cMsg_41qHCxmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_j8Zvgv8e, 1, m, NULL);
}

void Heavy_vSwell::cTabhead_Gxt7fDiV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7l67yeek, HV_BINOP_SUBTRACT, 0, m, &cBinop_7l67yeek_sendMessage);
}

void Heavy_vSwell::cMsg_pym31QM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_M4kw1Rrg_sendMessage);
}

void Heavy_vSwell::cSystem_M4kw1Rrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Pef9Q6kr_sendMessage);
}

void Heavy_vSwell::cVar_VwJd4xCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VfVh0pAo_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cDelay_MqFu0rxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MqFu0rxK, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6yev6IUj, 0, m, &cDelay_6yev6IUj_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5rPvTe9S, 0, m, &sTabread_5rPvTe9S_sendMessage);
}

void Heavy_vSwell::cDelay_6yev6IUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6yev6IUj, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5rPvTe9S, 0, m, &sTabread_5rPvTe9S_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6yev6IUj, 0, m, &cDelay_6yev6IUj_sendMessage);
}

void Heavy_vSwell::sTabread_5rPvTe9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_iBpN8VDL, HV_BINOP_SUBTRACT, 0, m, &cBinop_iBpN8VDL_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwell::cBinop_jlITOlCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_txCZqHBQ, HV_BINOP_MAX, 0, m, &cBinop_txCZqHBQ_sendMessage);
}

void Heavy_vSwell::cBinop_Pef9Q6kr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jlITOlCg, HV_BINOP_MULTIPLY, 0, m, &cBinop_jlITOlCg_sendMessage);
}

void Heavy_vSwell::cBinop_7l67yeek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0GnWQObU_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_5rPvTe9S, 0, m, &sTabread_5rPvTe9S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O1bUMsLm_sendMessage);
}

void Heavy_vSwell::cSystem_mviVPo0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iBpN8VDL, HV_BINOP_SUBTRACT, 1, m, &cBinop_iBpN8VDL_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6yev6IUj, 2, m, &cDelay_6yev6IUj_sendMessage);
}

void Heavy_vSwell::cMsg_VfVh0pAo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_mviVPo0e_sendMessage);
}

void Heavy_vSwell::cMsg_0GnWQObU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MqFu0rxK, 0, m, &cDelay_MqFu0rxK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_6yev6IUj, 0, m, &cDelay_6yev6IUj_sendMessage);
}

void Heavy_vSwell::cMsg_Y5RTPm8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_txCZqHBQ, HV_BINOP_MAX, 1, m, &cBinop_txCZqHBQ_sendMessage);
}

void Heavy_vSwell::cBinop_txCZqHBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7l67yeek, HV_BINOP_SUBTRACT, 1, m, &cBinop_7l67yeek_sendMessage);
}

void Heavy_vSwell::cCast_O1bUMsLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MqFu0rxK, 0, m, &cDelay_MqFu0rxK_sendMessage);
}

void Heavy_vSwell::cBinop_Hg2skV7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MqFu0rxK, 2, m, &cDelay_MqFu0rxK_sendMessage);
}

void Heavy_vSwell::cBinop_iBpN8VDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Hg2skV7m_sendMessage);
}

void Heavy_vSwell::cCast_0MvkJtLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VwJd4xCz, 0, m, &cVar_VwJd4xCz_sendMessage);
  cMsg_pym31QM2_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Gxt7fDiV, 0, m, &cTabhead_Gxt7fDiV_sendMessage);
}

void Heavy_vSwell::cUnop_shtzTY7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_GK49M8a7, m);
}

void Heavy_vSwell::cCast_OKKwMcIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Ionjj9Pb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cCast_E4BUM3Zo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6Nkth2CO_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_XwSRP1Hx, 0, m, &cVar_XwSRP1Hx_sendMessage);
}

void Heavy_vSwell::cCast_3m9x9cU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9unGfAx3, HV_BINOP_SUBTRACT, 0, m, &cBinop_9unGfAx3_sendMessage);
}

void Heavy_vSwell::cCast_Ub4FmXGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LmL0nFeZ, 0, m, &cVar_LmL0nFeZ_sendMessage);
}

void Heavy_vSwell::cBinop_9unGfAx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_utdqRiG1, 0, m, &cVar_utdqRiG1_sendMessage);
}

void Heavy_vSwell::cSend_6Nkth2CO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Y0QmYIK3_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_enoRXJHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Dfhu2Le2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_L0H2E7Ge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_0j4HefHj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwell::cMsg_1mdVPkje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wDsGC7V7, 0, m, NULL);
}

void Heavy_vSwell::cSend_7kYRNCCd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6mvdH8SZ_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cBinop_34ejzXlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_f5pIZrWE, 1, m, &cDelay_f5pIZrWE_sendMessage);
}

void Heavy_vSwell::cBinop_occrsAPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_shtzTY7U_sendMessage);
}

void Heavy_vSwell::cReceive_8WYwtcVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9unGfAx3, HV_BINOP_SUBTRACT, 1, m, &cBinop_9unGfAx3_sendMessage);
}

void Heavy_vSwell::cReceive_oQ9OoAg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9PW7H3Eg_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_iXfg5bnU, 0, m, &cVar_iXfg5bnU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZU4JVK4a, 0, m, &cVar_ZU4JVK4a_sendMessage);
  cMsg_MvxoD8VL_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_o6HeqYuH, 0, m, &cVar_o6HeqYuH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vNcH72bS, 0, m, &cVar_vNcH72bS_sendMessage);
  cMsg_mwUUXTYt_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_DGWWEJSi, 0, m, &cVar_DGWWEJSi_sendMessage);
  cMsg_nsrBTF7a_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_uFRVPOuf, 0, m, &cVar_uFRVPOuf_sendMessage);
  cMsg_Y5RTPm8G_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_VwJd4xCz, 0, m, &cVar_VwJd4xCz_sendMessage);
  cMsg_pym31QM2_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_Gxt7fDiV, 0, m, &cTabhead_Gxt7fDiV_sendMessage);
}

void Heavy_vSwell::cReceive_wUDcIsjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_g6tftt7m, 0, m, &cSlice_g6tftt7m_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_I1x5DUil, 0, m, &cSlice_I1x5DUil_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_BmiTcvFe, 0, m, &cSlice_BmiTcvFe_sendMessage);
}

void Heavy_vSwell::cReceive_B8pR1F7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_hmJ9xzyt, m);
}

void Heavy_vSwell::cReceive_Y0QmYIK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JuJw5TGK_sendMessage(_c, 0, m);
  cMsg_ow6jyiSM_sendMessage(_c, 0, m);
  cMsg_7qYTRW3D_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_qMZLMp4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3m9x9cU7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ub4FmXGd_sendMessage);
}

void Heavy_vSwell::cReceive_sRn3aMHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E4BUM3Zo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OKKwMcIG_sendMessage);
}

void Heavy_vSwell::cReceive_tFnTwFWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EsS8JCRu, 1, m, &cIf_EsS8JCRu_sendMessage);
}

void Heavy_vSwell::cReceive_ww4v0mQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HDrYTtJY, 1, m, &cVar_HDrYTtJY_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_uMf0UmrO, 1, m, &cPack_uMf0UmrO_sendMessage);
}

void Heavy_vSwell::cReceive_G6GUOarp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_uMf0UmrO, 2, m, &cPack_uMf0UmrO_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_uFEyszll, 1, m, &cDelay_uFEyszll_sendMessage);
}

void Heavy_vSwell::cReceive_FHfDKUpw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_gdzMyWl4, 1, m, &cPack_gdzMyWl4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kZFSrVSh, 1, m, &cVar_kZFSrVSh_sendMessage);
}

void Heavy_vSwell::cReceive_IXzahg95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_gdzMyWl4, 2, m, &cPack_gdzMyWl4_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_hJUoWu1l, 1, m, &cDelay_hJUoWu1l_sendMessage);
}

void Heavy_vSwell::cReceive_cSVfDbib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_gwZwqzgf, 2, m, &cPack_gwZwqzgf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_NzvYWfRC, 1, m, &cDelay_NzvYWfRC_sendMessage);
}

void Heavy_vSwell::cReceive_6mvdH8SZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uFRVPOuf, 1, m, &cVar_uFRVPOuf_sendMessage);
  cMsg_L0H2E7Ge_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_XwSRP1Hx, 1, m, &cVar_XwSRP1Hx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7SDKET0N, 1, m, &cVar_7SDKET0N_sendMessage);
}

void Heavy_vSwell::cReceive_SoR2sqzN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7kYRNCCd_sendMessage(_c, 0, m);
}

void Heavy_vSwell::cReceive_04r7aGd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_34ejzXlR_sendMessage);
}

void Heavy_vSwell::cReceive_dBjPdF3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_occrsAPe_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_1MsESKbQ, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwell::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4;

  // input and output vars
  hv_bufferf_t O0;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_j8Zvgv8e, VIf(I0));
    __hv_tabread_f(&sTabread_5rPvTe9S, VOf(Bf0));
    __hv_varread_f(&sVarf_aU9j3ewi, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_GNJAUDgN, VOf(Bf2));
    __hv_rpole_f(&sRPole_6DXhjDyB, VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_1MsESKbQ, VOf(Bf1));
    __hv_varread_f(&sVarf_GK49M8a7, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf3));
    __hv_gt_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_sqrt_f(VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    sEnv_process(this, &sEnv_A3Fb12fX, VIf(Bf3), &sEnv_A3Fb12fX_sendMessage);
    __hv_line_f(&sLine_wDsGC7V7, VOf(Bf3));
    __hv_varread_f(&sVarf_hmJ9xzyt, VOf(Bf1));
    __hv_pow_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_jRo4UGYG, VOf(Bf3));
    __hv_max_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_vSwell::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 1 channel(s)
  float **const bOut = &outputBuffers;

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwell::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 1 channel(s)
  float *const bOut = outputBuffers;

  int n = processInline(bIn, bOut, n4);

  

  return n;
}
