/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELL_HPP_
#define _HEAVY_CONTEXT_VSWELL_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlPack.h"
#include "HvControlCast.h"
#include "HvMath.h"
#include "HvControlBinop.h"
#include "HvSignalDel1.h"
#include "HvControlDelay.h"
#include "HvControlSystem.h"
#include "HvSignalTabwrite.h"
#include "HvTable.h"
#include "HvControlTabhead.h"
#include "HvSignalLine.h"
#include "HvControlUnop.h"
#include "HvControlIf.h"
#include "HvSignalTabread.h"
#include "HvControlSlice.h"
#include "HvSignalVar.h"
#include "HvSignalEnvelope.h"
#include "HvControlVar.h"
#include "HvSignalRPole.h"

class Heavy_vSwell : public HeavyContext {

 public:
  Heavy_vSwell(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwell();

  const char *getName() override { return "vSwell"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 1; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_BY_AUDIO_ON = 0xE7A7BB75, // Trigger_by_Audio_ON
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_A3Fb12fX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Ne4bvTK3_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_6b1HkK7o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_827oLLVL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8H2q190a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CxhLL2TE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TzJBAcCX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P4Mjly5c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jrRoNPfp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Yf3LM7S4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_naHSDtaS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_59PaVUJh_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_azPAt4yx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_zFn9rWkA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_P29F9CB0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_4B8yR1Mg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qlLXAXh4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_64lxKSdF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2FPvcnGx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3AeUOaQn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tuyI8ama_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WqZh53QX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_OV7TE30y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RiZxsITr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_KhQ5qXhK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_EnQ9BR4f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RorBrnxO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LmL0nFeZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_utdqRiG1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1V7ZqqFj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qF63uqOU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZlwTnX5A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d3Wnq9Ct_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_g6tftt7m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_I1x5DUil_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_BmiTcvFe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZU4JVK4a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_QjxigqjZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_4DkLsI5k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WhvR3LLq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4SSeoz74_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sD51ll8e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_cTDYvHaL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3OUmg7tE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_MUsNBwF2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5U3t8azz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iJHSKzeR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ue0Osn69_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YFhWyZZt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eeBexs9x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uipeM4sV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mwSntFmw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qnJHr7hu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_38vuJzIE_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_uFEyszll_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PX8Z4Qlz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_q4Oghbza_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_uMf0UmrO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7SDKET0N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JuJw5TGK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_80B916yo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ab6kJgmJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MbMXsY2Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_olS3A60e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TPzIUKmt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_hJUoWu1l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H0lcSVjw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FI7gTqzQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_gdzMyWl4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HDrYTtJY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ow6jyiSM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6cYcJlaR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RPuQ71s8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KHtl3QHR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bAobme5c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_gBKNx0hD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_NzvYWfRC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ex4VagOb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6nf1X8k8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_gwZwqzgf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kZFSrVSh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7qYTRW3D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2wkj0Z1f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QMWFPkIu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PwuEvIFy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XK8NBKtB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_EsS8JCRu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Dfhu2Le2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_iA3EGRll_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XwSRP1Hx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uFRVPOuf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MvxoD8VL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_RrstS4dI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_IYeDHhYk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_1htamooA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_unRYontC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9PW7H3Eg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YUVaARjc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iXfg5bnU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5H2FAvSQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_20DUGvhu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m5b70XPp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NCFLBMLm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zJ8jIwyD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_cVDKjMgi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_48bkOg7g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vPEauY2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0j4HefHj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_B9I5Lss3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_4I2hdYbQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fp4iSUJB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vNcH72bS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Peu7r6Hg_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_3Yfa400k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_o6HeqYuH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_h9nAQqzd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BwFnLBQt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_MBqoSe59_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_MdnuApO2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x67bTGgB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lEPcUXDR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VW2szoV8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QZTv9tUS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PhkkIvte_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XTcGYaki_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RKMyTJ4y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2OkfKukP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sdAaqySD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ROA6xa5H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ptdbe8cD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3KcGzxsr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_sBctZIfB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ALsyZdXq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K943kKAX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NpNxNSKt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4Miz0lVq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yEB0haEa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CYlJTeSs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iv9bsWvj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_efEDcENL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9I0pWd3l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dNs52Nbo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_avKsy8Tu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Mt7ujDjp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vgsJ88qw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mX8gdanI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8ujRTMUx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Ionjj9Pb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_f5pIZrWE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RhtskuxN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tTq4nau5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DGWWEJSi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mwUUXTYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_lsR14xWm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0h8xHIcU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yE26mIXR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dSwNihov_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x2z2nD2d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kKowXaKt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yxcSDYn6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nsrBTF7a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_48OnyBUa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Fb7AMfoh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_rpEG4Hn3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_dsiJFuFz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_1pvgt8kL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_pL5ZPjuS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oJInV9Wt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j0nUBvyA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B5oix101_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3lH7rKJi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Zkal29Lm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_41qHCxmN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_Gxt7fDiV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pym31QM2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_M4kw1Rrg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VwJd4xCz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_MqFu0rxK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_6yev6IUj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_5rPvTe9S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jlITOlCg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Pef9Q6kr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7l67yeek_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_mviVPo0e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VfVh0pAo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0GnWQObU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y5RTPm8G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_txCZqHBQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O1bUMsLm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hg2skV7m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iBpN8VDL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0MvkJtLo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_shtzTY7U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OKKwMcIG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E4BUM3Zo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3m9x9cU7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ub4FmXGd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9unGfAx3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_6Nkth2CO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_enoRXJHf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L0H2E7Ge_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1mdVPkje_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7kYRNCCd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_34ejzXlR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_occrsAPe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8WYwtcVd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oQ9OoAg9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wUDcIsjL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_B8pR1F7q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Y0QmYIK3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qMZLMp4b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sRn3aMHz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tFnTwFWg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ww4v0mQQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_G6GUOarp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FHfDKUpw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IXzahg95_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cSVfDbib_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6mvdH8SZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SoR2sqzN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_04r7aGd7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dBjPdF3z_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_j8Zvgv8e;
  SignalTabread sTabread_5rPvTe9S;
  SignalRPole sRPole_6DXhjDyB;
  SignalEnvelope sEnv_A3Fb12fX;
  SignalLine sLine_wDsGC7V7;
  ControlSlice cSlice_6b1HkK7o;
  ControlSlice cSlice_827oLLVL;
  ControlVar cVar_8H2q190a;
  ControlIf cIf_CxhLL2TE;
  ControlBinop cBinop_jrRoNPfp;
  ControlSlice cSlice_azPAt4yx;
  ControlSlice cSlice_zFn9rWkA;
  ControlVar cVar_P29F9CB0;
  ControlIf cIf_4B8yR1Mg;
  ControlBinop cBinop_2FPvcnGx;
  ControlVar cVar_LmL0nFeZ;
  ControlVar cVar_utdqRiG1;
  ControlBinop cBinop_1V7ZqqFj;
  ControlBinop cBinop_qF63uqOU;
  ControlSlice cSlice_g6tftt7m;
  ControlSlice cSlice_I1x5DUil;
  ControlSlice cSlice_BmiTcvFe;
  ControlVar cVar_ZU4JVK4a;
  ControlIf cIf_WhvR3LLq;
  ControlBinop cBinop_4SSeoz74;
  ControlIf cIf_sD51ll8e;
  ControlIf cIf_cTDYvHaL;
  ControlIf cIf_3OUmg7tE;
  ControlIf cIf_MUsNBwF2;
  ControlBinop cBinop_5U3t8azz;
  ControlBinop cBinop_iJHSKzeR;
  ControlBinop cBinop_ue0Osn69;
  ControlBinop cBinop_qnJHr7hu;
  ControlDelay cDelay_uFEyszll;
  ControlPack cPack_uMf0UmrO;
  ControlVar cVar_7SDKET0N;
  ControlDelay cDelay_hJUoWu1l;
  ControlPack cPack_gdzMyWl4;
  ControlVar cVar_HDrYTtJY;
  ControlDelay cDelay_NzvYWfRC;
  ControlPack cPack_gwZwqzgf;
  ControlVar cVar_kZFSrVSh;
  ControlIf cIf_EsS8JCRu;
  ControlVar cVar_XwSRP1Hx;
  ControlVar cVar_uFRVPOuf;
  SignalVarf sVarf_jRo4UGYG;
  ControlDelay cDelay_1htamooA;
  ControlVar cVar_iXfg5bnU;
  ControlBinop cBinop_20DUGvhu;
  ControlBinop cBinop_m5b70XPp;
  ControlBinop cBinop_NCFLBMLm;
  ControlVar cVar_zJ8jIwyD;
  ControlSlice cSlice_B9I5Lss3;
  ControlSlice cSlice_4I2hdYbQ;
  ControlVar cVar_fp4iSUJB;
  ControlVar cVar_vNcH72bS;
  ControlVar cVar_o6HeqYuH;
  ControlVar cVar_h9nAQqzd;
  ControlVar cVar_BwFnLBQt;
  ControlSlice cSlice_MBqoSe59;
  ControlSlice cSlice_MdnuApO2;
  ControlBinop cBinop_x67bTGgB;
  ControlBinop cBinop_lEPcUXDR;
  ControlBinop cBinop_VW2szoV8;
  ControlBinop cBinop_QZTv9tUS;
  ControlBinop cBinop_PhkkIvte;
  ControlBinop cBinop_2OkfKukP;
  ControlBinop cBinop_sdAaqySD;
  ControlBinop cBinop_ROA6xa5H;
  ControlBinop cBinop_Ptdbe8cD;
  ControlBinop cBinop_yEB0haEa;
  ControlBinop cBinop_avKsy8Tu;
  ControlDelay cDelay_f5pIZrWE;
  ControlVar cVar_DGWWEJSi;
  ControlBinop cBinop_0h8xHIcU;
  ControlBinop cBinop_yE26mIXR;
  SignalVarf sVarf_GNJAUDgN;
  ControlBinop cBinop_x2z2nD2d;
  ControlBinop cBinop_kKowXaKt;
  ControlBinop cBinop_yxcSDYn6;
  SignalVarf sVarf_aU9j3ewi;
  ControlDelay cDelay_Fb7AMfoh;
  ControlDelay cDelay_rpEG4Hn3;
  ControlBinop cBinop_1pvgt8kL;
  HvTable hTable_pL5ZPjuS;
  ControlBinop cBinop_j0nUBvyA;
  ControlTabhead cTabhead_Gxt7fDiV;
  ControlVar cVar_VwJd4xCz;
  ControlDelay cDelay_MqFu0rxK;
  ControlDelay cDelay_6yev6IUj;
  ControlBinop cBinop_jlITOlCg;
  ControlBinop cBinop_Pef9Q6kr;
  ControlBinop cBinop_7l67yeek;
  ControlBinop cBinop_txCZqHBQ;
  ControlBinop cBinop_Hg2skV7m;
  ControlBinop cBinop_iBpN8VDL;
  ControlBinop cBinop_9unGfAx3;
  ControlBinop cBinop_enoRXJHf;
  ControlBinop cBinop_34ejzXlR;
  ControlBinop cBinop_occrsAPe;
  SignalVarf sVarf_hmJ9xzyt;
  SignalVarf sVarf_GK49M8a7;
  SignalVarf sVarf_1MsESKbQ;
};

#endif // _HEAVY_CONTEXT_VSWELL_HPP_
