/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_vSwellST.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_vSwellST *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_vSwellST_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_vSwellST_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_vSwellST));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_vSwellST(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_vSwellST_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_vSwellST();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_vSwellST::Heavy_vSwellST(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sTabwrite_init(&sTabwrite_CdvsRcNp, &hTable_YpRDHph9);
  numBytes += sTabwrite_init(&sTabwrite_kb2gjGOb, &hTable_uFWJsq4x);
  numBytes += sRPole_init(&sRPole_9JHhh2DL);
  numBytes += sEnv_init(&sEnv_O2AmY1oK, 1024, 512);
  numBytes += sTabread_init(&sTabread_2KcliyWp, &hTable_uFWJsq4x, true);
  numBytes += sLine_init(&sLine_222mFory);
  numBytes += sTabread_init(&sTabread_cUC8o8U8, &hTable_YpRDHph9, true);
  numBytes += cSlice_init(&cSlice_7VbupVu4, 1, -1);
  numBytes += cSlice_init(&cSlice_cI6Z1FGq, 1, -1);
  numBytes += cVar_init_f(&cVar_xBSm7BlG, 0.0f);
  numBytes += cIf_init(&cIf_XJ1Faklk, false);
  numBytes += cBinop_init(&cBinop_SlhLEum7, 0.0f); // __neq
  numBytes += cSlice_init(&cSlice_JUG0xN2w, 1, -1);
  numBytes += cSlice_init(&cSlice_TEpxpWej, 1, -1);
  numBytes += cVar_init_f(&cVar_PSqM3F7n, 0.0f);
  numBytes += cIf_init(&cIf_sKJQ7ny0, false);
  numBytes += cBinop_init(&cBinop_lJviYH3w, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_jkpLWTTn, 0.0f);
  numBytes += cVar_init_f(&cVar_RoGBhmHo, 0.0f);
  numBytes += cBinop_init(&cBinop_ACIJJdgx, 0.0f); // __gt
  numBytes += cBinop_init(&cBinop_gEklobgf, 0.0f); // __lt
  numBytes += cSlice_init(&cSlice_7Q8cayNO, 2, 1);
  numBytes += cSlice_init(&cSlice_o32rQ62A, 1, 1);
  numBytes += cSlice_init(&cSlice_L8Bp27G0, 0, 1);
  numBytes += cVar_init_f(&cVar_v54bnCAw, 0.0f);
  numBytes += cIf_init(&cIf_L7kaK97k, false);
  numBytes += cIf_init(&cIf_WrApayPB, false);
  numBytes += cIf_init(&cIf_aCwe7xBF, false);
  numBytes += cIf_init(&cIf_vY5oIdLS, false);
  numBytes += cIf_init(&cIf_TIOJmAPg, false);
  numBytes += cBinop_init(&cBinop_bEmY2NuN, 0.0f); // __eq
  numBytes += cDelay_init(this, &cDelay_crZ4DWd5, 10.0f);
  numBytes += cPack_init(&cPack_wzT1p82m, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_oR9RaF37, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_rbTeW6NI, 10.0f);
  numBytes += cPack_init(&cPack_0vlnxtKG, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_TBURiorO, 1e-07f);
  numBytes += cDelay_init(this, &cDelay_wg3Hggdv, 10.0f);
  numBytes += cPack_init(&cPack_8HZzjL8E, 3, 0.0f, 0.0f, 0.0f);
  numBytes += cVar_init_f(&cVar_WYN5seaD, 1e-07f);
  numBytes += cVar_init_f(&cVar_p9R4Veec, 1e-07f);
  numBytes += cVar_init_f(&cVar_4j5Bw3B8, 1e-07f);
  numBytes += sVarf_init(&sVarf_nSIt1W9B, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_4ZCjP8if, 0.0f);
  numBytes += cVar_init_f(&cVar_ddbHZqtt, 20.0f);
  numBytes += cBinop_init(&cBinop_vXubqncP, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_9Yd6poXA, 0.0f);
  numBytes += cSlice_init(&cSlice_UIpwCWmU, 1, -1);
  numBytes += cSlice_init(&cSlice_h443Egts, 1, -1);
  numBytes += cVar_init_f(&cVar_nJCJUDXe, 0.0f);
  numBytes += cVar_init_f(&cVar_dGm9l6Uh, 20.0f);
  numBytes += cVar_init_f(&cVar_N5B4K761, 0.0f);
  numBytes += cVar_init_f(&cVar_zIFbIU4t, 0.0f);
  numBytes += cVar_init_f(&cVar_l3mclgNO, 0.0f);
  numBytes += cSlice_init(&cSlice_sT0lI1nR, 1, 1);
  numBytes += cSlice_init(&cSlice_Q0d39UKx, 0, 1);
  numBytes += cBinop_init(&cBinop_dbuRFfTt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xDrQdLGF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mDf7fPJn, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_rU0SyOXB, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_maXWES7F, 20.0f); // __div
  numBytes += cBinop_init(&cBinop_QDGiWGBH, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_KH2ZkQNH, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_f1KKDWeF, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_1Ojd2xkM, 5.0f);
  numBytes += cVar_init_f(&cVar_4qGX91lt, 500.0f);
  numBytes += cBinop_init(&cBinop_v5Fem3cD, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_SLkpeqU2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Zdysxj61, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_VoEyVweu, 0.0f);
  numBytes += cDelay_init(this, &cDelay_R6xNm4oz, 0.0f);
  numBytes += hTable_init(&hTable_YpRDHph9, 256);
  numBytes += cTabhead_init(&cTabhead_JILbwuP2, &hTable_YpRDHph9);
  numBytes += cVar_init_s(&cVar_PRNypbmN, "del-1001-swell");
  numBytes += cDelay_init(this, &cDelay_dWa1YdQl, 8.0f);
  numBytes += cDelay_init(this, &cDelay_3V12M4Bx, 0.0f);
  numBytes += cBinop_init(&cBinop_e6I2epNB, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_FQMRPOaJ, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_L9esbgDI, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_rByiNi0b, 0.0f); // __sub
  numBytes += cDelay_init(this, &cDelay_PA02tLgK, 0.0f);
  numBytes += cDelay_init(this, &cDelay_67M87B0h, 0.0f);
  numBytes += hTable_init(&hTable_uFWJsq4x, 256);
  numBytes += cTabhead_init(&cTabhead_w6LqVWm2, &hTable_uFWJsq4x);
  numBytes += cVar_init_s(&cVar_wdUEyXOE, "del-1001-swell2");
  numBytes += cDelay_init(this, &cDelay_Fz6VgIKo, 8.0f);
  numBytes += cDelay_init(this, &cDelay_owzoZciV, 0.0f);
  numBytes += cBinop_init(&cBinop_hED9oZof, 8.0f); // __mul
  numBytes += cBinop_init(&cBinop_z4E0180n, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_AZ0UAKdy, 0.0f); // __max
  numBytes += cBinop_init(&cBinop_NSJ2Gitf, 0.0f); // __sub
  numBytes += cBinop_init(&cBinop_ECjFHQZz, 2.0f); // __sub
  numBytes += sVarf_init(&sVarf_uZprvAwH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vc6Wk48D, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_l7O5tnI7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mq6lTRJW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kL3lJr1y, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_vSwellST::~Heavy_vSwellST() {
  sEnv_free(&sEnv_O2AmY1oK);
  cPack_free(&cPack_wzT1p82m);
  cPack_free(&cPack_0vlnxtKG);
  cPack_free(&cPack_8HZzjL8E);
  hTable_free(&hTable_YpRDHph9);
  hTable_free(&hTable_uFWJsq4x);
}

HvTable *Heavy_vSwellST::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0xB4039215: return &hTable_YpRDHph9; // del-1001-swell
    case 0x505A9C79: return &hTable_uFWJsq4x; // del-1001-swell2
    default: return nullptr;
  }
}

void Heavy_vSwellST::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xCFF35931: { // Attack_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OlhvPphJ_sendMessage);
      break;
    }
    case 0x4397AE0: { // Attack_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Anv5KpA8_sendMessage);
      break;
    }
    case 0x73ACB90E: { // Mid_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4bdH3jGg_sendMessage);
      break;
    }
    case 0x4675584E: { // Mid_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KmLIAYkr_sendMessage);
      break;
    }
    case 0x558F437A: { // Release_ms
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ShxCmFeS_sendMessage);
      break;
    }
    case 0x8D204657: { // Shape
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UlUnlt4p_sendMessage);
      break;
    }
    case 0x2D669F6F: { // SubEnv_Level
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TiFMUdtO_sendMessage);
      break;
    }
    case 0x7BABB594: { // Threshold_High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IbgoIx1X_sendMessage);
      break;
    }
    case 0xA0E82E9F: { // Threshold_Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kMupGmDd_sendMessage);
      break;
    }
    case 0x145892E8: { // Threshold_Strict
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cbFS6maj_sendMessage);
      break;
    }
    case 0xCB36B160: { // Trigger_Delay
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XQp2qcgY_sendMessage);
      break;
    }
    case 0x5DF5B524: { // Trigger_EXT
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hHKIqpJZ_sendMessage);
      break;
    }
    case 0x4E6E7C40: { // Trigger_Left
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IyqEGMSb_sendMessage);
      break;
    }
    case 0xB181ABB6: { // Trigger_Right
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_r9yQDdN4_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6WcnzuJx_sendMessage);
      break;
    }
    case 0x67E37CA3: { // __hv_notein
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RbKo4kS5_sendMessage);
      break;
    }
    case 0xA2F0F2D3: { // ecancel
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_C4k4sbGW_sendMessage);
      break;
    }
    case 0xC698CFF8: { // subenv
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pNw3jbiE_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_vSwellST::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Attack_Level";
        info->hash = 0xCFF35931;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.6f;
        break;
      }
      case 1: {
        info->name = "Attack_ms";
        info->hash = 0x4397AE0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 3000.0f;
        info->defaultVal = 400.0f;
        break;
      }
      case 2: {
        info->name = "Mid_Level";
        info->hash = 0x73ACB90E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 3.0f;
        info->defaultVal = 0.65f;
        break;
      }
      case 3: {
        info->name = "Mid_ms";
        info->hash = 0x4675584E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 1000.0f;
        break;
      }
      case 4: {
        info->name = "Release_ms";
        info->hash = 0x558F437A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 10.0f;
        info->maxVal = 4000.0f;
        info->defaultVal = 2200.0f;
        break;
      }
      case 5: {
        info->name = "Shape";
        info->hash = 0x8D204657;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.1f;
        info->maxVal = 3.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 6: {
        info->name = "SubEnv_Level";
        info->hash = 0x2D669F6F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1e-07f;
        info->maxVal = 0.7f;
        info->defaultVal = 1e-07f;
        break;
      }
      case 7: {
        info->name = "Threshold_High";
        info->hash = 0x7BABB594;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 20.0f;
        info->maxVal = 90.0f;
        info->defaultVal = 52.0f;
        break;
      }
      case 8: {
        info->name = "Threshold_Low";
        info->hash = 0xA0E82E9F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.3f;
        info->maxVal = 8.0f;
        info->defaultVal = 1.5f;
        break;
      }
      case 9: {
        info->name = "Threshold_Strict";
        info->hash = 0x145892E8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 10: {
        info->name = "Trigger_Delay";
        info->hash = 0xCB36B160;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 50.0f;
        info->defaultVal = 2.0f;
        break;
      }
      case 11: {
        info->name = "Trigger_EXT";
        info->hash = 0x5DF5B524;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Trigger_Left";
        info->hash = 0x4E6E7C40;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 13: {
        info->name = "Trigger_Right";
        info->hash = 0xB181ABB6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 14;
}



/*
 * Send Function Implementations
 */


void Heavy_vSwellST::sEnv_O2AmY1oK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ACIJJdgx, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ACIJJdgx_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gEklobgf, HV_BINOP_LESS_THAN, 0, m, &cBinop_gEklobgf_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_WMZX54dt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7VbupVu4, 0, m, &cSlice_7VbupVu4_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cI6Z1FGq, 0, m, &cSlice_cI6Z1FGq_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cPah4tIY_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0DW6nJpl_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_7VbupVu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_xBSm7BlG, 0, m, &cVar_xBSm7BlG_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_xBSm7BlG, 0, m, &cVar_xBSm7BlG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_cI6Z1FGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_SlhLEum7, HV_BINOP_NEQ, 1, m, &cBinop_SlhLEum7_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_xBSm7BlG, 1, m, &cVar_xBSm7BlG_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_SlhLEum7, HV_BINOP_NEQ, 1, m, &cBinop_SlhLEum7_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_xBSm7BlG, 1, m, &cVar_xBSm7BlG_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_xBSm7BlG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_xpMtiQcD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_XJ1Faklk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gtNB7djY_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OpYsh4H6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_OpYsh4H6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xBSm7BlG, 0, m, &cVar_xBSm7BlG_sendMessage);
}

void Heavy_vSwellST::cCast_gtNB7djY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SlhLEum7, HV_BINOP_NEQ, 1, m, &cBinop_SlhLEum7_sendMessage);
}

void Heavy_vSwellST::cBinop_SlhLEum7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XJ1Faklk, 1, m, &cIf_XJ1Faklk_sendMessage);
}

void Heavy_vSwellST::cCast_cPah4tIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SlhLEum7, HV_BINOP_NEQ, 0, m, &cBinop_SlhLEum7_sendMessage);
}

void Heavy_vSwellST::cCast_0DW6nJpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XJ1Faklk, 0, m, &cIf_XJ1Faklk_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_3vqesCHe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JUG0xN2w, 0, m, &cSlice_JUG0xN2w_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TEpxpWej, 0, m, &cSlice_TEpxpWej_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NQL9RBOF_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RGnIljwv_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_JUG0xN2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_PSqM3F7n, 0, m, &cVar_PSqM3F7n_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_PSqM3F7n, 0, m, &cVar_PSqM3F7n_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_TEpxpWej_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_lJviYH3w, HV_BINOP_NEQ, 1, m, &cBinop_lJviYH3w_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_PSqM3F7n, 1, m, &cVar_PSqM3F7n_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_lJviYH3w, HV_BINOP_NEQ, 1, m, &cBinop_lJviYH3w_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_PSqM3F7n, 1, m, &cVar_PSqM3F7n_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_PSqM3F7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HziUKbKv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cIf_sKJQ7ny0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YlJXKAg7_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gP1dPBHh_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cCast_YlJXKAg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lJviYH3w, HV_BINOP_NEQ, 1, m, &cBinop_lJviYH3w_sendMessage);
}

void Heavy_vSwellST::cCast_gP1dPBHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PSqM3F7n, 0, m, &cVar_PSqM3F7n_sendMessage);
}

void Heavy_vSwellST::cBinop_lJviYH3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sKJQ7ny0, 1, m, &cIf_sKJQ7ny0_sendMessage);
}

void Heavy_vSwellST::cCast_NQL9RBOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lJviYH3w, HV_BINOP_NEQ, 0, m, &cBinop_lJviYH3w_sendMessage);
}

void Heavy_vSwellST::cCast_RGnIljwv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sKJQ7ny0, 0, m, &cIf_sKJQ7ny0_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_xpMtiQcD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bze21dJr_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vMw3QEjQ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_bze21dJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RoGBhmHo, 0, m, &cVar_RoGBhmHo_sendMessage);
}

void Heavy_vSwellST::cCast_vMw3QEjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zughEPoo_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NSK1z3xZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SfqmPK7C_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_HziUKbKv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ScelqhT7_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YT0JV9AI_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_ScelqhT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jkpLWTTn, 0, m, &cVar_jkpLWTTn_sendMessage);
}

void Heavy_vSwellST::cCast_YT0JV9AI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZT0ZcfIH_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_jkpLWTTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ACIJJdgx, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ACIJJdgx_sendMessage);
}

void Heavy_vSwellST::cVar_RoGBhmHo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gEklobgf, HV_BINOP_LESS_THAN, 1, m, &cBinop_gEklobgf_sendMessage);
}

void Heavy_vSwellST::cBinop_ACIJJdgx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WMZX54dt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_gEklobgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3vqesCHe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_zughEPoo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ACIJJdgx, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ACIJJdgx_sendMessage);
}

void Heavy_vSwellST::cMsg_ZT0ZcfIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, -1e+37f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gEklobgf, HV_BINOP_LESS_THAN, 1, m, &cBinop_gEklobgf_sendMessage);
}

void Heavy_vSwellST::cSlice_7Q8cayNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Txww2UIX_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_o32rQ62A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_vY5oIdLS, 0, m, &cIf_vY5oIdLS_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_WrApayPB, 0, m, &cIf_WrApayPB_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_L8Bp27G0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cIf_onMessage(_c, &Context(_c)->cIf_TIOJmAPg, 0, m, &cIf_TIOJmAPg_sendMessage);
      cIf_onMessage(_c, &Context(_c)->cIf_aCwe7xBF, 0, m, &cIf_aCwe7xBF_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_v54bnCAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2o89uXph_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_L7kaK97k, 0, m, &cIf_L7kaK97k_sendMessage);
}

void Heavy_vSwellST::cUnop_BjO0Xra3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OqKiSQoi_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bEmY2NuN, HV_BINOP_EQ, 1, m, &cBinop_bEmY2NuN_sendMessage);
}

void Heavy_vSwellST::cUnop_YOY6cd3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OqKiSQoi_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bEmY2NuN, HV_BINOP_EQ, 1, m, &cBinop_bEmY2NuN_sendMessage);
}

void Heavy_vSwellST::cIf_L7kaK97k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cUnop_onMessage(_c, HV_UNOP_CEIL, m, &cUnop_YOY6cd3x_sendMessage);
      break;
    }
    case 1: {
      cUnop_onMessage(_c, HV_UNOP_FLOOR, m, &cUnop_BjO0Xra3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_2o89uXph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_L7kaK97k, 1, m, &cIf_L7kaK97k_sendMessage);
}

void Heavy_vSwellST::cIf_WrApayPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_jgqeuFxX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_aCwe7xBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_vY5oIdLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_jgqeuFxX_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cIf_TIOJmAPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_Txww2UIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bEmY2NuN, HV_BINOP_EQ, 0, m, &cBinop_bEmY2NuN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_DWuaccLo_sendMessage);
}

void Heavy_vSwellST::cBinop_OqKiSQoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z6ff3pLH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qCEbBFnG_sendMessage);
}

void Heavy_vSwellST::cBinop_bEmY2NuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PoDdcwt9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ve44AjbC_sendMessage);
}

void Heavy_vSwellST::cCast_Ve44AjbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TIOJmAPg, 1, m, &cIf_TIOJmAPg_sendMessage);
}

void Heavy_vSwellST::cCast_PoDdcwt9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WrApayPB, 1, m, &cIf_WrApayPB_sendMessage);
}

void Heavy_vSwellST::cCast_qCEbBFnG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aCwe7xBF, 1, m, &cIf_aCwe7xBF_sendMessage);
}

void Heavy_vSwellST::cCast_z6ff3pLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vY5oIdLS, 1, m, &cIf_vY5oIdLS_sendMessage);
}

void Heavy_vSwellST::cBinop_DWuaccLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_vSwellST::cSwitchcase_vi6WpnpF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5U6LQdpj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5U6LQdpj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_crZ4DWd5, 1, m, &cDelay_crZ4DWd5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R4qIWhGC_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_crZ4DWd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_crZ4DWd5, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BhMmWMIu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JV1rCw2E_sendMessage);
  cSwitchcase_fz6l51cx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_5U6LQdpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_crZ4DWd5, 0, m, &cDelay_crZ4DWd5_sendMessage);
}

void Heavy_vSwellST::cCast_R4qIWhGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_crZ4DWd5, 0, m, &cDelay_crZ4DWd5_sendMessage);
}

void Heavy_vSwellST::cPack_wzT1p82m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_41LvKVTC_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_oR9RaF37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dOFaQMHN_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_BK5Ad5Vw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_vi6WpnpF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_YYLNBb3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_wzT1p82m, 0, m, &cPack_wzT1p82m_sendMessage);
}

void Heavy_vSwellST::cCast_mT0kOy2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oR9RaF37, 0, m, &cVar_oR9RaF37_sendMessage);
}

void Heavy_vSwellST::cMsg_dOFaQMHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_222mFory, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_41LvKVTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_222mFory, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_fz6l51cx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NVT5xFft_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NVT5xFft_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rbTeW6NI, 1, m, &cDelay_rbTeW6NI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RgxoyrNs_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_rbTeW6NI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rbTeW6NI, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pWTpjXTo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V2XJr8Ty_sendMessage);
  cSwitchcase_HjMGmy6r_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_NVT5xFft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rbTeW6NI, 0, m, &cDelay_rbTeW6NI_sendMessage);
}

void Heavy_vSwellST::cCast_RgxoyrNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rbTeW6NI, 0, m, &cDelay_rbTeW6NI_sendMessage);
}

void Heavy_vSwellST::cPack_0vlnxtKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LPgBUT26_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_TBURiorO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yKk8Ixpk_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_31YZ9sms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_fz6l51cx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_JV1rCw2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_0vlnxtKG, 0, m, &cPack_0vlnxtKG_sendMessage);
}

void Heavy_vSwellST::cCast_BhMmWMIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TBURiorO, 0, m, &cVar_TBURiorO_sendMessage);
}

void Heavy_vSwellST::cMsg_yKk8Ixpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_222mFory, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_LPgBUT26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_222mFory, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_HjMGmy6r_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KCgSkXzM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KCgSkXzM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wg3Hggdv, 1, m, &cDelay_wg3Hggdv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aRmpPo7y_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_wg3Hggdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wg3Hggdv, m);
}

void Heavy_vSwellST::cMsg_KCgSkXzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wg3Hggdv, 0, m, &cDelay_wg3Hggdv_sendMessage);
}

void Heavy_vSwellST::cCast_aRmpPo7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wg3Hggdv, 0, m, &cDelay_wg3Hggdv_sendMessage);
}

void Heavy_vSwellST::cPack_8HZzjL8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_clu2jW8y_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_WYN5seaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FnOcm3Hz_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cMsg_LG2Q4hcu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "stop");
  cSwitchcase_HjMGmy6r_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_pWTpjXTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WYN5seaD, 0, m, &cVar_WYN5seaD_sendMessage);
}

void Heavy_vSwellST::cCast_V2XJr8Ty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_8HZzjL8E, 0, m, &cPack_8HZzjL8E_sendMessage);
}

void Heavy_vSwellST::cMsg_FnOcm3Hz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  sLine_onMessage(_c, &Context(_c)->sLine_222mFory, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_clu2jW8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 1);
  msg_setElementToFrom(m, 1, n, 2);
  sLine_onMessage(_c, &Context(_c)->sLine_222mFory, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_0QX7Ff2n_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4F84PaHi_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_4F84PaHi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NSK1z3xZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SfqmPK7C_sendMessage);
}

void Heavy_vSwellST::cVar_p9R4Veec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lwQO8PfY_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_4j5Bw3B8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_8HZzjL8E, 1, m, &cPack_8HZzjL8E_sendMessage);
}

void Heavy_vSwellST::cMsg_S5B1kmJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_UWZNW0FE_sendMessage);
}

void Heavy_vSwellST::cSystem_UWZNW0FE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xDrQdLGF, HV_BINOP_MULTIPLY, 1, m, &cBinop_xDrQdLGF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dbuRFfTt, HV_BINOP_MULTIPLY, 1, m, &cBinop_dbuRFfTt_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_9usmgRyQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cMsg_IQEkHL26_sendMessage(_c, 0, m);
      break;
    }
    case 0x7A5B032D: { // "stop"
      cMsg_IQEkHL26_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M6aIzuOY_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_4ZCjP8if_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4ZCjP8if, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4ZCjP8if, 0, m, &cDelay_4ZCjP8if_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9Yd6poXA, 0, m, &cVar_9Yd6poXA_sendMessage);
}

void Heavy_vSwellST::cCast_M6aIzuOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IQEkHL26_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_4ZCjP8if, 0, m, &cDelay_4ZCjP8if_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9Yd6poXA, 0, m, &cVar_9Yd6poXA_sendMessage);
}

void Heavy_vSwellST::cMsg_ltlTEjOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ueNCXrPT_sendMessage);
}

void Heavy_vSwellST::cSystem_ueNCXrPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_wLqBJ7KF_sendMessage);
}

void Heavy_vSwellST::cVar_ddbHZqtt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vXubqncP, HV_BINOP_MULTIPLY, 0, m, &cBinop_vXubqncP_sendMessage);
}

void Heavy_vSwellST::cMsg_IQEkHL26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4ZCjP8if, 0, m, &cDelay_4ZCjP8if_sendMessage);
}

void Heavy_vSwellST::cBinop_A4qTsyNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4ZCjP8if, 2, m, &cDelay_4ZCjP8if_sendMessage);
}

void Heavy_vSwellST::cBinop_wLqBJ7KF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vXubqncP, HV_BINOP_MULTIPLY, 1, m, &cBinop_vXubqncP_sendMessage);
}

void Heavy_vSwellST::cBinop_vXubqncP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_A4qTsyNM_sendMessage);
}

void Heavy_vSwellST::cVar_9Yd6poXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mDf7fPJn, HV_BINOP_SUBTRACT, 0, m, &cBinop_mDf7fPJn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_LESS_THAN_EQL, 0.0f, 0, m, &cBinop_1nTBiXB8_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_YJKyyEkc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sfOqih7G_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uFb0AhNQ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cCast_sfOqih7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_l3mclgNO, 0, m, &cVar_l3mclgNO_sendMessage);
}

void Heavy_vSwellST::cCast_uFb0AhNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iF7i1DBb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4qGwV2ki_sendMessage);
}

void Heavy_vSwellST::cSwitchcase_klqMygol_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UIpwCWmU, 0, m, &cSlice_UIpwCWmU_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_h443Egts, 0, m, &cSlice_h443Egts_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NP40EMcp_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_sT0lI1nR, 0, m, &cSlice_sT0lI1nR_sendMessage);
      cSlice_onMessage(_c, &Context(_c)->cSlice_Q0d39UKx, 0, m, &cSlice_Q0d39UKx_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UjyasfrC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SV17J5Uc_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cSlice_UIpwCWmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_EwNbd80L_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cMsg_EwNbd80L_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_h443Egts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HQbGgh2A_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qA8dnhmA_sendMessage);
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HQbGgh2A_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qA8dnhmA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cVar_nJCJUDXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Is7xNG4I_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z6uhuyJi_sendMessage);
}

void Heavy_vSwellST::cVar_dGm9l6Uh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_r7R9ZI5z_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cSwitchcase_r7R9ZI5z_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_99QOCfyS_sendMessage);
      break;
    }
    default: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_xDrQdLGF, HV_BINOP_MULTIPLY, 0, m, &cBinop_xDrQdLGF_sendMessage);
      cBinop_onMessage(_c, &Context(_c)->cBinop_maXWES7F, HV_BINOP_DIVIDE, 1, m, &cBinop_maXWES7F_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_ddbHZqtt, 0, m, &cVar_ddbHZqtt_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cCast_99QOCfyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VsElHC26_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cVar_N5B4K761_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f1KKDWeF, HV_BINOP_SUBTRACT, 1, m, &cBinop_f1KKDWeF_sendMessage);
}

void Heavy_vSwellST::cVar_zIFbIU4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_l3mclgNO, 0, m, &cVar_l3mclgNO_sendMessage);
}

void Heavy_vSwellST::cVar_l3mclgNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rU0SyOXB, HV_BINOP_ADD, 0, m, &cBinop_rU0SyOXB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KH2ZkQNH, HV_BINOP_ADD, 0, m, &cBinop_KH2ZkQNH_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_nSIt1W9B, m);
}

void Heavy_vSwellST::cSlice_sT0lI1nR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Is7xNG4I_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z6uhuyJi_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cSlice_Q0d39UKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cw7sEsWI_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8c0YMtdI_sendMessage);
      break;
    }
    case 1: {
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_i5cHx3Kj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9Yd6poXA, 1, m, &cVar_9Yd6poXA_sendMessage);
}

void Heavy_vSwellST::cBinop_dbuRFfTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_i5cHx3Kj_sendMessage);
}

void Heavy_vSwellST::cBinop_xDrQdLGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ubgc3c0Q_sendMessage);
}

void Heavy_vSwellST::cBinop_ubgc3c0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mDf7fPJn, HV_BINOP_SUBTRACT, 1, m, &cBinop_mDf7fPJn_sendMessage);
}

void Heavy_vSwellST::cBinop_mDf7fPJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9Yd6poXA, 1, m, &cVar_9Yd6poXA_sendMessage);
}

void Heavy_vSwellST::cMsg_NKON1ABG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cSwitchcase_9usmgRyQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_I2gwtwkk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_9usmgRyQ_onMessage(_c, NULL, 0, m, NULL);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KH2ZkQNH, HV_BINOP_ADD, 1, m, &cBinop_KH2ZkQNH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rU0SyOXB, HV_BINOP_ADD, 1, m, &cBinop_rU0SyOXB_sendMessage);
}

void Heavy_vSwellST::cBinop_1nTBiXB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YJKyyEkc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cBinop_rU0SyOXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_l3mclgNO, 1, m, &cVar_l3mclgNO_sendMessage);
}

void Heavy_vSwellST::cBinop_maXWES7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QDGiWGBH, HV_BINOP_DIVIDE, 1, m, &cBinop_QDGiWGBH_sendMessage);
}

void Heavy_vSwellST::cBinop_QDGiWGBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KH2ZkQNH, HV_BINOP_ADD, 1, m, &cBinop_KH2ZkQNH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_rU0SyOXB, HV_BINOP_ADD, 1, m, &cBinop_rU0SyOXB_sendMessage);
}

void Heavy_vSwellST::cCast_Is7xNG4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dbuRFfTt, HV_BINOP_MULTIPLY, 0, m, &cBinop_dbuRFfTt_sendMessage);
}

void Heavy_vSwellST::cCast_z6uhuyJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_maXWES7F, HV_BINOP_DIVIDE, 0, m, &cBinop_maXWES7F_sendMessage);
}

void Heavy_vSwellST::cCast_8c0YMtdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f1KKDWeF, HV_BINOP_SUBTRACT, 0, m, &cBinop_f1KKDWeF_sendMessage);
}

void Heavy_vSwellST::cCast_Cw7sEsWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zIFbIU4t, 1, m, &cVar_zIFbIU4t_sendMessage);
}

void Heavy_vSwellST::cCast_4qGwV2ki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zIFbIU4t, 0, m, &cVar_zIFbIU4t_sendMessage);
}

void Heavy_vSwellST::cCast_iF7i1DBb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I2gwtwkk_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_KH2ZkQNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_N5B4K761, 0, m, &cVar_N5B4K761_sendMessage);
}

void Heavy_vSwellST::cMsg_EwNbd80L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cSwitchcase_9usmgRyQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_WPFkN3L8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_nJCJUDXe, 1, m, &cVar_nJCJUDXe_sendMessage);
}

void Heavy_vSwellST::cMsg_VsElHC26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 20.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xDrQdLGF, HV_BINOP_MULTIPLY, 0, m, &cBinop_xDrQdLGF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_maXWES7F, HV_BINOP_DIVIDE, 1, m, &cBinop_maXWES7F_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ddbHZqtt, 0, m, &cVar_ddbHZqtt_sendMessage);
}

void Heavy_vSwellST::cCast_qA8dnhmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PGShEPBO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KH2ZkQNH, HV_BINOP_ADD, 0, m, &cBinop_KH2ZkQNH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_l3mclgNO, 1, m, &cVar_l3mclgNO_sendMessage);
}

void Heavy_vSwellST::cCast_HQbGgh2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EwNbd80L_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_f1KKDWeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QDGiWGBH, HV_BINOP_DIVIDE, 0, m, &cBinop_QDGiWGBH_sendMessage);
}

void Heavy_vSwellST::cCast_PGShEPBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I2gwtwkk_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_NP40EMcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nJCJUDXe, 0, m, &cVar_nJCJUDXe_sendMessage);
}

void Heavy_vSwellST::cCast_SV17J5Uc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WPFkN3L8_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cCast_UjyasfrC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NKON1ABG_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_lTxK4OKq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ghx1z4mp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ghx1z4mp_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1Ojd2xkM, 1, m, &cDelay_1Ojd2xkM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aL50cWf7_sendMessage);
      break;
    }
  }
}

void Heavy_vSwellST::cDelay_1Ojd2xkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1Ojd2xkM, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mT0kOy2A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YYLNBb3v_sendMessage);
  cSwitchcase_vi6WpnpF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_Ghx1z4mp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1Ojd2xkM, 0, m, &cDelay_1Ojd2xkM_sendMessage);
}

void Heavy_vSwellST::cCast_aL50cWf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1Ojd2xkM, 0, m, &cDelay_1Ojd2xkM_sendMessage);
}

void Heavy_vSwellST::cVar_4qGX91lt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v5Fem3cD, HV_BINOP_MULTIPLY, 0, m, &cBinop_v5Fem3cD_sendMessage);
}

void Heavy_vSwellST::cMsg_TMVtRdYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Qz7MkanN_sendMessage);
}

void Heavy_vSwellST::cSystem_Qz7MkanN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NjQw0xTe_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_v5Fem3cD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_MslTetVY_sendMessage);
}

void Heavy_vSwellST::cBinop_6G5PM8MX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v5Fem3cD, HV_BINOP_MULTIPLY, 1, m, &cBinop_v5Fem3cD_sendMessage);
}

void Heavy_vSwellST::cMsg_NjQw0xTe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6G5PM8MX_sendMessage);
}

void Heavy_vSwellST::cBinop_MslTetVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_gJ0D5EQl_sendMessage);
}

void Heavy_vSwellST::cBinop_gJ0D5EQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ZKhbJgvP_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Zdysxj61, m);
}

void Heavy_vSwellST::cBinop_ZKhbJgvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_SLkpeqU2, m);
}

void Heavy_vSwellST::cMsg_VgpSBWom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_rjAxvIUT_sendMessage);
}

void Heavy_vSwellST::cSystem_rjAxvIUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_xvyfd6CZ_sendMessage);
}

void Heavy_vSwellST::cDelay_VoEyVweu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VoEyVweu, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_R6xNm4oz, 0, m, &cDelay_R6xNm4oz_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VoEyVweu, 0, m, &cDelay_VoEyVweu_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_CdvsRcNp, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_R6xNm4oz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_R6xNm4oz, m);
  cMsg_0ZOXSR5k_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_mcCUhDtJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_EXTeVQmI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cBinop_c4Z5e2PL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DiKPpWNR_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_YpRDHph9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lP0CbGGo_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VoEyVweu, 2, m, &cDelay_VoEyVweu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WTQOFhjq_sendMessage);
}

void Heavy_vSwellST::cMsg_DiKPpWNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_YpRDHph9, 0, m, &hTable_YpRDHph9_sendMessage);
}

void Heavy_vSwellST::cBinop_xvyfd6CZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_c4Z5e2PL_sendMessage);
}

void Heavy_vSwellST::cMsg_0ZOXSR5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_YpRDHph9, 0, m, &hTable_YpRDHph9_sendMessage);
}

void Heavy_vSwellST::cCast_WTQOFhjq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VoEyVweu, 0, m, &cDelay_VoEyVweu_sendMessage);
}

void Heavy_vSwellST::cMsg_lP0CbGGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_R6xNm4oz, 2, m, &cDelay_R6xNm4oz_sendMessage);
}

void Heavy_vSwellST::cMsg_EXTeVQmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_CdvsRcNp, 1, m, NULL);
}

void Heavy_vSwellST::cTabhead_JILbwuP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FQMRPOaJ, HV_BINOP_SUBTRACT, 0, m, &cBinop_FQMRPOaJ_sendMessage);
}

void Heavy_vSwellST::cMsg_lSTCytDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_X0CXe5KC_sendMessage);
}

void Heavy_vSwellST::cSystem_X0CXe5KC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_KWeMc5gN_sendMessage);
}

void Heavy_vSwellST::cVar_PRNypbmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lblU6qyM_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_dWa1YdQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_dWa1YdQl, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3V12M4Bx, 0, m, &cDelay_3V12M4Bx_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_cUC8o8U8, 0, m, &sTabread_cUC8o8U8_sendMessage);
}

void Heavy_vSwellST::cDelay_3V12M4Bx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3V12M4Bx, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_cUC8o8U8, 0, m, &sTabread_cUC8o8U8_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3V12M4Bx, 0, m, &cDelay_3V12M4Bx_sendMessage);
}

void Heavy_vSwellST::sTabread_cUC8o8U8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_rByiNi0b, HV_BINOP_SUBTRACT, 0, m, &cBinop_rByiNi0b_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_e6I2epNB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L9esbgDI, HV_BINOP_MAX, 0, m, &cBinop_L9esbgDI_sendMessage);
}

void Heavy_vSwellST::cBinop_KWeMc5gN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e6I2epNB, HV_BINOP_MULTIPLY, 0, m, &cBinop_e6I2epNB_sendMessage);
}

void Heavy_vSwellST::cBinop_FQMRPOaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xkD6i71x_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_cUC8o8U8, 0, m, &sTabread_cUC8o8U8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bJz9ii7b_sendMessage);
}

void Heavy_vSwellST::cSystem_5yTEKNS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rByiNi0b, HV_BINOP_SUBTRACT, 1, m, &cBinop_rByiNi0b_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3V12M4Bx, 2, m, &cDelay_3V12M4Bx_sendMessage);
}

void Heavy_vSwellST::cMsg_lblU6qyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5yTEKNS1_sendMessage);
}

void Heavy_vSwellST::cMsg_xkD6i71x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_dWa1YdQl, 0, m, &cDelay_dWa1YdQl_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_3V12M4Bx, 0, m, &cDelay_3V12M4Bx_sendMessage);
}

void Heavy_vSwellST::cMsg_7S3LaGYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_L9esbgDI, HV_BINOP_MAX, 1, m, &cBinop_L9esbgDI_sendMessage);
}

void Heavy_vSwellST::cBinop_L9esbgDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FQMRPOaJ, HV_BINOP_SUBTRACT, 1, m, &cBinop_FQMRPOaJ_sendMessage);
}

void Heavy_vSwellST::cCast_bJz9ii7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dWa1YdQl, 0, m, &cDelay_dWa1YdQl_sendMessage);
}

void Heavy_vSwellST::cBinop_c25SiOQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_dWa1YdQl, 2, m, &cDelay_dWa1YdQl_sendMessage);
}

void Heavy_vSwellST::cBinop_rByiNi0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_c25SiOQK_sendMessage);
}

void Heavy_vSwellST::cCast_J1eoKZHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PRNypbmN, 0, m, &cVar_PRNypbmN_sendMessage);
  cMsg_lSTCytDd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JILbwuP2, 0, m, &cTabhead_JILbwuP2_sendMessage);
}

void Heavy_vSwellST::cMsg_QKa0asol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_PKKTcHMV_sendMessage);
}

void Heavy_vSwellST::cSystem_PKKTcHMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_4OiffCEQ_sendMessage);
}

void Heavy_vSwellST::cDelay_PA02tLgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PA02tLgK, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_67M87B0h, 0, m, &cDelay_67M87B0h_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PA02tLgK, 0, m, &cDelay_PA02tLgK_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_kb2gjGOb, 1, m, NULL);
}

void Heavy_vSwellST::cDelay_67M87B0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_67M87B0h, m);
  cMsg_6wz8rvl9_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cSwitchcase_bWncjC1Y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_iTYibxJw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_vSwellST::cBinop_VhB6vuEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6y1dYxSe_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::hTable_uFWJsq4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jxDpHghc_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_PA02tLgK, 2, m, &cDelay_PA02tLgK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KG3mZR89_sendMessage);
}

void Heavy_vSwellST::cMsg_6y1dYxSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_uFWJsq4x, 0, m, &hTable_uFWJsq4x_sendMessage);
}

void Heavy_vSwellST::cBinop_4OiffCEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_VhB6vuEq_sendMessage);
}

void Heavy_vSwellST::cMsg_6wz8rvl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_uFWJsq4x, 0, m, &hTable_uFWJsq4x_sendMessage);
}

void Heavy_vSwellST::cCast_KG3mZR89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PA02tLgK, 0, m, &cDelay_PA02tLgK_sendMessage);
}

void Heavy_vSwellST::cMsg_jxDpHghc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_67M87B0h, 2, m, &cDelay_67M87B0h_sendMessage);
}

void Heavy_vSwellST::cMsg_iTYibxJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_kb2gjGOb, 1, m, NULL);
}

void Heavy_vSwellST::cTabhead_w6LqVWm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z4E0180n, HV_BINOP_SUBTRACT, 0, m, &cBinop_z4E0180n_sendMessage);
}

void Heavy_vSwellST::cMsg_yg0ffp3p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Kws9lJMP_sendMessage);
}

void Heavy_vSwellST::cSystem_Kws9lJMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_t4FUbl6Y_sendMessage);
}

void Heavy_vSwellST::cVar_wdUEyXOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lcgN1q9o_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cDelay_Fz6VgIKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Fz6VgIKo, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_owzoZciV, 0, m, &cDelay_owzoZciV_sendMessage);
  sTabread_onMessage(_c, &Context(_c)->sTabread_2KcliyWp, 0, m, &sTabread_2KcliyWp_sendMessage);
}

void Heavy_vSwellST::cDelay_owzoZciV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_owzoZciV, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_2KcliyWp, 0, m, &sTabread_2KcliyWp_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_owzoZciV, 0, m, &cDelay_owzoZciV_sendMessage);
}

void Heavy_vSwellST::sTabread_2KcliyWp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_NSJ2Gitf, HV_BINOP_SUBTRACT, 0, m, &cBinop_NSJ2Gitf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_vSwellST::cBinop_hED9oZof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AZ0UAKdy, HV_BINOP_MAX, 0, m, &cBinop_AZ0UAKdy_sendMessage);
}

void Heavy_vSwellST::cBinop_t4FUbl6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hED9oZof, HV_BINOP_MULTIPLY, 0, m, &cBinop_hED9oZof_sendMessage);
}

void Heavy_vSwellST::cBinop_z4E0180n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S0Zjn7Xl_sendMessage(_c, 0, m);
  sTabread_onMessage(_c, &Context(_c)->sTabread_2KcliyWp, 0, m, &sTabread_2KcliyWp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3HBWTRlu_sendMessage);
}

void Heavy_vSwellST::cSystem_LBYUFa2Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NSJ2Gitf, HV_BINOP_SUBTRACT, 1, m, &cBinop_NSJ2Gitf_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_owzoZciV, 2, m, &cDelay_owzoZciV_sendMessage);
}

void Heavy_vSwellST::cMsg_lcgN1q9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_LBYUFa2Y_sendMessage);
}

void Heavy_vSwellST::cMsg_S0Zjn7Xl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Fz6VgIKo, 0, m, &cDelay_Fz6VgIKo_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_owzoZciV, 0, m, &cDelay_owzoZciV_sendMessage);
}

void Heavy_vSwellST::cMsg_rmVUluX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cBinop_onMessage(_c, &Context(_c)->cBinop_AZ0UAKdy, HV_BINOP_MAX, 1, m, &cBinop_AZ0UAKdy_sendMessage);
}

void Heavy_vSwellST::cBinop_AZ0UAKdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z4E0180n, HV_BINOP_SUBTRACT, 1, m, &cBinop_z4E0180n_sendMessage);
}

void Heavy_vSwellST::cCast_3HBWTRlu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Fz6VgIKo, 0, m, &cDelay_Fz6VgIKo_sendMessage);
}

void Heavy_vSwellST::cBinop_BVcCEbgS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Fz6VgIKo, 2, m, &cDelay_Fz6VgIKo_sendMessage);
}

void Heavy_vSwellST::cBinop_NSJ2Gitf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_BVcCEbgS_sendMessage);
}

void Heavy_vSwellST::cCast_4bOsGeIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wdUEyXOE, 0, m, &cVar_wdUEyXOE_sendMessage);
  cMsg_yg0ffp3p_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_w6LqVWm2, 0, m, &cTabhead_w6LqVWm2_sendMessage);
}

void Heavy_vSwellST::cUnop_ENjJMXEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_mq6lTRJW, m);
}

void Heavy_vSwellST::cCast_SfqmPK7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lTxK4OKq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cCast_NSK1z3xZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EDPgERMP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_p9R4Veec, 0, m, &cVar_p9R4Veec_sendMessage);
}

void Heavy_vSwellST::cCast_Nov4XiNw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ECjFHQZz, HV_BINOP_SUBTRACT, 0, m, &cBinop_ECjFHQZz_sendMessage);
}

void Heavy_vSwellST::cCast_Ixxc32QH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jkpLWTTn, 0, m, &cVar_jkpLWTTn_sendMessage);
}

void Heavy_vSwellST::cBinop_ECjFHQZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RoGBhmHo, 0, m, &cVar_RoGBhmHo_sendMessage);
}

void Heavy_vSwellST::cSend_EDPgERMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_C4k4sbGW_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_jgqeuFxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0QX7Ff2n_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_mULhCMFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 25.0f);
  cSwitchcase_klqMygol_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_vSwellST::cMsg_lwQO8PfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 3.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_222mFory, 0, m, NULL);
}

void Heavy_vSwellST::cSend_sWJoOobC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pNw3jbiE_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cBinop_EX2V7YIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1Ojd2xkM, 1, m, &cDelay_1Ojd2xkM_sendMessage);
}

void Heavy_vSwellST::cBinop_qQYXKMRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_ENjJMXEw_sendMessage);
}

void Heavy_vSwellST::cReceive_kMupGmDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ECjFHQZz, HV_BINOP_SUBTRACT, 1, m, &cBinop_ECjFHQZz_sendMessage);
}

void Heavy_vSwellST::cReceive_6WcnzuJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ltlTEjOY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ddbHZqtt, 0, m, &cVar_ddbHZqtt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_v54bnCAw, 0, m, &cVar_v54bnCAw_sendMessage);
  cMsg_S5B1kmJN_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_N5B4K761, 0, m, &cVar_N5B4K761_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dGm9l6Uh, 0, m, &cVar_dGm9l6Uh_sendMessage);
  cMsg_TMVtRdYc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_4qGX91lt, 0, m, &cVar_4qGX91lt_sendMessage);
  cMsg_VgpSBWom_sendMessage(_c, 0, m);
  cMsg_QKa0asol_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_4j5Bw3B8, 0, m, &cVar_4j5Bw3B8_sendMessage);
  cMsg_7S3LaGYH_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_PRNypbmN, 0, m, &cVar_PRNypbmN_sendMessage);
  cMsg_lSTCytDd_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_JILbwuP2, 0, m, &cTabhead_JILbwuP2_sendMessage);
  cMsg_rmVUluX5_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_wdUEyXOE, 0, m, &cVar_wdUEyXOE_sendMessage);
  cMsg_yg0ffp3p_sendMessage(_c, 0, m);
  cTabhead_onMessage(_c, &Context(_c)->cTabhead_w6LqVWm2, 0, m, &cTabhead_w6LqVWm2_sendMessage);
}

void Heavy_vSwellST::cReceive_RbKo4kS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSlice_onMessage(_c, &Context(_c)->cSlice_7Q8cayNO, 0, m, &cSlice_7Q8cayNO_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_o32rQ62A, 0, m, &cSlice_o32rQ62A_sendMessage);
  cSlice_onMessage(_c, &Context(_c)->cSlice_L8Bp27G0, 0, m, &cSlice_L8Bp27G0_sendMessage);
}

void Heavy_vSwellST::cReceive_UlUnlt4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_uZprvAwH, m);
}

void Heavy_vSwellST::cReceive_C4k4sbGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BK5Ad5Vw_sendMessage(_c, 0, m);
  cMsg_31YZ9sms_sendMessage(_c, 0, m);
  cMsg_LG2Q4hcu_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_hHKIqpJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NSK1z3xZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SfqmPK7C_sendMessage);
}

void Heavy_vSwellST::cReceive_OlhvPphJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TBURiorO, 1, m, &cVar_TBURiorO_sendMessage);
  cPack_onMessage(_c, &Context(_c)->cPack_wzT1p82m, 1, m, &cPack_wzT1p82m_sendMessage);
}

void Heavy_vSwellST::cReceive_Anv5KpA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_wzT1p82m, 2, m, &cPack_wzT1p82m_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_crZ4DWd5, 1, m, &cDelay_crZ4DWd5_sendMessage);
}

void Heavy_vSwellST::cReceive_4bdH3jGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_0vlnxtKG, 1, m, &cPack_0vlnxtKG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WYN5seaD, 1, m, &cVar_WYN5seaD_sendMessage);
}

void Heavy_vSwellST::cReceive_KmLIAYkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_0vlnxtKG, 2, m, &cPack_0vlnxtKG_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_rbTeW6NI, 1, m, &cDelay_rbTeW6NI_sendMessage);
}

void Heavy_vSwellST::cReceive_ShxCmFeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cPack_onMessage(_c, &Context(_c)->cPack_8HZzjL8E, 2, m, &cPack_8HZzjL8E_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wg3Hggdv, 1, m, &cDelay_wg3Hggdv_sendMessage);
}

void Heavy_vSwellST::cReceive_pNw3jbiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4j5Bw3B8, 1, m, &cVar_4j5Bw3B8_sendMessage);
  cMsg_mULhCMFs_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_p9R4Veec, 1, m, &cVar_p9R4Veec_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oR9RaF37, 1, m, &cVar_oR9RaF37_sendMessage);
}

void Heavy_vSwellST::cReceive_TiFMUdtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sWJoOobC_sendMessage(_c, 0, m);
}

void Heavy_vSwellST::cReceive_XQp2qcgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 3.0f, 0, m, &cBinop_EX2V7YIQ_sendMessage);
}

void Heavy_vSwellST::cReceive_IyqEGMSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_vc6Wk48D, m);
}

void Heavy_vSwellST::cReceive_r9yQDdN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_l7O5tnI7, m);
}

void Heavy_vSwellST::cReceive_IbgoIx1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Nov4XiNw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ixxc32QH_sendMessage);
}

void Heavy_vSwellST::cReceive_cbFS6maj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_qQYXKMRc_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_kL3lJr1y, m);
}




/*
 * Context Process Implementation
 */

int Heavy_vSwellST::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_tabwrite_f(&sTabwrite_CdvsRcNp, VIf(I0));
    __hv_tabwrite_f(&sTabwrite_kb2gjGOb, VIf(I1));
    __hv_varread_f(&sVarf_vc6Wk48D, VOf(Bf0));
    __hv_varread_f(&sVarf_l7O5tnI7, VOf(Bf1));
    __hv_mul_f(VIf(I1), VIf(Bf1), VOf(Bf1));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Zdysxj61, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_SLkpeqU2, VOf(Bf1));
    __hv_rpole_f(&sRPole_9JHhh2DL, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_kL3lJr1y, VOf(Bf0));
    __hv_varread_f(&sVarf_mq6lTRJW, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf3), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf2));
    __hv_gt_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_sqrt_f(VIf(Bf3), VOf(Bf3));
    __hv_and_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf2), 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f, 80.0f);
    __hv_div_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf2), VOf(Bf2));
    sEnv_process(this, &sEnv_O2AmY1oK, VIf(Bf2), &sEnv_O2AmY1oK_sendMessage);
    __hv_tabread_f(&sTabread_2KcliyWp, VOf(Bf2));
    __hv_line_f(&sLine_222mFory, VOf(Bf0));
    __hv_varread_f(&sVarf_uZprvAwH, VOf(Bf1));
    __hv_pow_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_nSIt1W9B, VOf(Bf0));
    __hv_max_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f, 2.5f);
    __hv_min_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));
    __hv_tabread_f(&sTabread_cUC8o8U8, VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf1), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_vSwellST::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_vSwellST::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
