/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_VSWELLST_HPP_
#define _HEAVY_CONTEXT_VSWELLST_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlBinop.h"
#include "HvMath.h"
#include "HvSignalRPole.h"
#include "HvControlSystem.h"
#include "HvControlDelay.h"
#include "HvControlSlice.h"
#include "HvSignalDel1.h"
#include "HvControlIf.h"
#include "HvSignalVar.h"
#include "HvControlVar.h"
#include "HvControlUnop.h"
#include "HvSignalTabread.h"
#include "HvSignalLine.h"
#include "HvControlTabhead.h"
#include "HvSignalTabwrite.h"
#include "HvControlPack.h"
#include "HvSignalEnvelope.h"
#include "HvTable.h"
#include "HvControlCast.h"

class Heavy_vSwellST : public HeavyContext {

 public:
  Heavy_vSwellST(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_vSwellST();

  const char *getName() override { return "vSwellST"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        ATTACK_LEVEL = 0xCFF35931, // Attack_Level
        ATTACK_MS = 0x4397AE0, // Attack_ms
        MID_LEVEL = 0x73ACB90E, // Mid_Level
        MID_MS = 0x4675584E, // Mid_ms
        RELEASE_MS = 0x558F437A, // Release_ms
        SHAPE = 0x8D204657, // Shape
        SUBENV_LEVEL = 0x2D669F6F, // SubEnv_Level
        THRESHOLD_HIGH = 0x7BABB594, // Threshold_High
        THRESHOLD_LOW = 0xA0E82E9F, // Threshold_Low
        THRESHOLD_STRICT = 0x145892E8, // Threshold_Strict
        TRIGGER_DELAY = 0xCB36B160, // Trigger_Delay
        TRIGGER_EXT = 0x5DF5B524, // Trigger_EXT
        TRIGGER_LEFT = 0x4E6E7C40, // Trigger_Left
        TRIGGER_RIGHT = 0xB181ABB6, // Trigger_Right
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void sEnv_O2AmY1oK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WMZX54dt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7VbupVu4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_cI6Z1FGq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xBSm7BlG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XJ1Faklk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OpYsh4H6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gtNB7djY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SlhLEum7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cPah4tIY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0DW6nJpl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3vqesCHe_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_JUG0xN2w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_TEpxpWej_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PSqM3F7n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_sKJQ7ny0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YlJXKAg7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gP1dPBHh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lJviYH3w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NQL9RBOF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RGnIljwv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_xpMtiQcD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_bze21dJr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vMw3QEjQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HziUKbKv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_ScelqhT7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YT0JV9AI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jkpLWTTn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RoGBhmHo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ACIJJdgx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gEklobgf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zughEPoo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZT0ZcfIH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_7Q8cayNO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_o32rQ62A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_L8Bp27G0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_v54bnCAw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_BjO0Xra3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_YOY6cd3x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_L7kaK97k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2o89uXph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WrApayPB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_aCwe7xBF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vY5oIdLS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_TIOJmAPg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Txww2UIX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OqKiSQoi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bEmY2NuN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ve44AjbC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PoDdcwt9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qCEbBFnG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z6ff3pLH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DWuaccLo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_vi6WpnpF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_crZ4DWd5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5U6LQdpj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R4qIWhGC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_wzT1p82m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oR9RaF37_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BK5Ad5Vw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YYLNBb3v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mT0kOy2A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dOFaQMHN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_41LvKVTC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_fz6l51cx_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_rbTeW6NI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NVT5xFft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RgxoyrNs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_0vlnxtKG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TBURiorO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_31YZ9sms_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JV1rCw2E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BhMmWMIu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yKk8Ixpk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LPgBUT26_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HjMGmy6r_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_wg3Hggdv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KCgSkXzM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aRmpPo7y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cPack_8HZzjL8E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WYN5seaD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LG2Q4hcu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pWTpjXTo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V2XJr8Ty_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FnOcm3Hz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_clu2jW8y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0QX7Ff2n_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_4F84PaHi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_p9R4Veec_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4j5Bw3B8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S5B1kmJN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_UWZNW0FE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_9usmgRyQ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_4ZCjP8if_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M6aIzuOY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ltlTEjOY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ueNCXrPT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ddbHZqtt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IQEkHL26_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A4qTsyNM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wLqBJ7KF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vXubqncP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9Yd6poXA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YJKyyEkc_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_sfOqih7G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uFb0AhNQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_klqMygol_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_UIpwCWmU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_h443Egts_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nJCJUDXe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dGm9l6Uh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_r7R9ZI5z_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_99QOCfyS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_N5B4K761_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zIFbIU4t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_l3mclgNO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_sT0lI1nR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_Q0d39UKx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i5cHx3Kj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dbuRFfTt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xDrQdLGF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ubgc3c0Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mDf7fPJn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NKON1ABG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I2gwtwkk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1nTBiXB8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rU0SyOXB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_maXWES7F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QDGiWGBH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Is7xNG4I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z6uhuyJi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8c0YMtdI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cw7sEsWI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4qGwV2ki_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iF7i1DBb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KH2ZkQNH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EwNbd80L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WPFkN3L8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VsElHC26_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qA8dnhmA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HQbGgh2A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f1KKDWeF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PGShEPBO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NP40EMcp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SV17J5Uc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UjyasfrC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lTxK4OKq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_1Ojd2xkM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ghx1z4mp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aL50cWf7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4qGX91lt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TMVtRdYc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Qz7MkanN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v5Fem3cD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6G5PM8MX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NjQw0xTe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MslTetVY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gJ0D5EQl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZKhbJgvP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VgpSBWom_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_rjAxvIUT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VoEyVweu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_R6xNm4oz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mcCUhDtJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_c4Z5e2PL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_YpRDHph9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DiKPpWNR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xvyfd6CZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0ZOXSR5k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WTQOFhjq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lP0CbGGo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EXTeVQmI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_JILbwuP2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lSTCytDd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_X0CXe5KC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PRNypbmN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_dWa1YdQl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_3V12M4Bx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_cUC8o8U8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e6I2epNB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KWeMc5gN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FQMRPOaJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_5yTEKNS1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lblU6qyM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xkD6i71x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7S3LaGYH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L9esbgDI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bJz9ii7b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c25SiOQK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rByiNi0b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_J1eoKZHa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QKa0asol_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_PKKTcHMV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_PA02tLgK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_67M87B0h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bWncjC1Y_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_VhB6vuEq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_uFWJsq4x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6y1dYxSe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4OiffCEQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6wz8rvl9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KG3mZR89_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jxDpHghc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iTYibxJw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cTabhead_w6LqVWm2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yg0ffp3p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Kws9lJMP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wdUEyXOE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_Fz6VgIKo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_owzoZciV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sTabread_2KcliyWp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hED9oZof_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t4FUbl6Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z4E0180n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_LBYUFa2Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lcgN1q9o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S0Zjn7Xl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rmVUluX5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AZ0UAKdy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3HBWTRlu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BVcCEbgS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NSJ2Gitf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4bOsGeIX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ENjJMXEw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SfqmPK7C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NSK1z3xZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Nov4XiNw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ixxc32QH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ECjFHQZz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_EDPgERMP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jgqeuFxX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mULhCMFs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lwQO8PfY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_sWJoOobC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EX2V7YIQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qQYXKMRc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kMupGmDd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6WcnzuJx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RbKo4kS5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UlUnlt4p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_C4k4sbGW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hHKIqpJZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OlhvPphJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Anv5KpA8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4bdH3jGg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KmLIAYkr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ShxCmFeS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pNw3jbiE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TiFMUdtO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XQp2qcgY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IyqEGMSb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_r9yQDdN4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IbgoIx1X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cbFS6maj_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalTabwrite sTabwrite_CdvsRcNp;
  SignalTabwrite sTabwrite_kb2gjGOb;
  SignalRPole sRPole_9JHhh2DL;
  SignalEnvelope sEnv_O2AmY1oK;
  SignalTabread sTabread_2KcliyWp;
  SignalLine sLine_222mFory;
  SignalTabread sTabread_cUC8o8U8;
  ControlSlice cSlice_7VbupVu4;
  ControlSlice cSlice_cI6Z1FGq;
  ControlVar cVar_xBSm7BlG;
  ControlIf cIf_XJ1Faklk;
  ControlBinop cBinop_SlhLEum7;
  ControlSlice cSlice_JUG0xN2w;
  ControlSlice cSlice_TEpxpWej;
  ControlVar cVar_PSqM3F7n;
  ControlIf cIf_sKJQ7ny0;
  ControlBinop cBinop_lJviYH3w;
  ControlVar cVar_jkpLWTTn;
  ControlVar cVar_RoGBhmHo;
  ControlBinop cBinop_ACIJJdgx;
  ControlBinop cBinop_gEklobgf;
  ControlSlice cSlice_7Q8cayNO;
  ControlSlice cSlice_o32rQ62A;
  ControlSlice cSlice_L8Bp27G0;
  ControlVar cVar_v54bnCAw;
  ControlIf cIf_L7kaK97k;
  ControlBinop cBinop_2o89uXph;
  ControlIf cIf_WrApayPB;
  ControlIf cIf_aCwe7xBF;
  ControlIf cIf_vY5oIdLS;
  ControlIf cIf_TIOJmAPg;
  ControlBinop cBinop_Txww2UIX;
  ControlBinop cBinop_OqKiSQoi;
  ControlBinop cBinop_bEmY2NuN;
  ControlBinop cBinop_DWuaccLo;
  ControlDelay cDelay_crZ4DWd5;
  ControlPack cPack_wzT1p82m;
  ControlVar cVar_oR9RaF37;
  ControlDelay cDelay_rbTeW6NI;
  ControlPack cPack_0vlnxtKG;
  ControlVar cVar_TBURiorO;
  ControlDelay cDelay_wg3Hggdv;
  ControlPack cPack_8HZzjL8E;
  ControlVar cVar_WYN5seaD;
  ControlVar cVar_p9R4Veec;
  ControlVar cVar_4j5Bw3B8;
  SignalVarf sVarf_nSIt1W9B;
  ControlDelay cDelay_4ZCjP8if;
  ControlVar cVar_ddbHZqtt;
  ControlBinop cBinop_A4qTsyNM;
  ControlBinop cBinop_wLqBJ7KF;
  ControlBinop cBinop_vXubqncP;
  ControlVar cVar_9Yd6poXA;
  ControlSlice cSlice_UIpwCWmU;
  ControlSlice cSlice_h443Egts;
  ControlVar cVar_nJCJUDXe;
  ControlVar cVar_dGm9l6Uh;
  ControlVar cVar_N5B4K761;
  ControlVar cVar_zIFbIU4t;
  ControlVar cVar_l3mclgNO;
  ControlSlice cSlice_sT0lI1nR;
  ControlSlice cSlice_Q0d39UKx;
  ControlBinop cBinop_i5cHx3Kj;
  ControlBinop cBinop_dbuRFfTt;
  ControlBinop cBinop_xDrQdLGF;
  ControlBinop cBinop_ubgc3c0Q;
  ControlBinop cBinop_mDf7fPJn;
  ControlBinop cBinop_1nTBiXB8;
  ControlBinop cBinop_rU0SyOXB;
  ControlBinop cBinop_maXWES7F;
  ControlBinop cBinop_QDGiWGBH;
  ControlBinop cBinop_KH2ZkQNH;
  ControlBinop cBinop_f1KKDWeF;
  ControlDelay cDelay_1Ojd2xkM;
  ControlVar cVar_4qGX91lt;
  ControlBinop cBinop_v5Fem3cD;
  ControlBinop cBinop_6G5PM8MX;
  SignalVarf sVarf_SLkpeqU2;
  ControlBinop cBinop_MslTetVY;
  ControlBinop cBinop_gJ0D5EQl;
  ControlBinop cBinop_ZKhbJgvP;
  SignalVarf sVarf_Zdysxj61;
  ControlDelay cDelay_VoEyVweu;
  ControlDelay cDelay_R6xNm4oz;
  ControlBinop cBinop_c4Z5e2PL;
  HvTable hTable_YpRDHph9;
  ControlBinop cBinop_xvyfd6CZ;
  ControlTabhead cTabhead_JILbwuP2;
  ControlVar cVar_PRNypbmN;
  ControlDelay cDelay_dWa1YdQl;
  ControlDelay cDelay_3V12M4Bx;
  ControlBinop cBinop_e6I2epNB;
  ControlBinop cBinop_KWeMc5gN;
  ControlBinop cBinop_FQMRPOaJ;
  ControlBinop cBinop_L9esbgDI;
  ControlBinop cBinop_c25SiOQK;
  ControlBinop cBinop_rByiNi0b;
  ControlDelay cDelay_PA02tLgK;
  ControlDelay cDelay_67M87B0h;
  ControlBinop cBinop_VhB6vuEq;
  HvTable hTable_uFWJsq4x;
  ControlBinop cBinop_4OiffCEQ;
  ControlTabhead cTabhead_w6LqVWm2;
  ControlVar cVar_wdUEyXOE;
  ControlDelay cDelay_Fz6VgIKo;
  ControlDelay cDelay_owzoZciV;
  ControlBinop cBinop_hED9oZof;
  ControlBinop cBinop_t4FUbl6Y;
  ControlBinop cBinop_z4E0180n;
  ControlBinop cBinop_AZ0UAKdy;
  ControlBinop cBinop_BVcCEbgS;
  ControlBinop cBinop_NSJ2Gitf;
  ControlBinop cBinop_ECjFHQZz;
  ControlBinop cBinop_jgqeuFxX;
  ControlBinop cBinop_EX2V7YIQ;
  ControlBinop cBinop_qQYXKMRc;
  SignalVarf sVarf_uZprvAwH;
  SignalVarf sVarf_vc6Wk48D;
  SignalVarf sVarf_l7O5tnI7;
  SignalVarf sVarf_mq6lTRJW;
  SignalVarf sVarf_kL3lJr1y;
};

#endif // _HEAVY_CONTEXT_VSWELLST_HPP_
